#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   Issue #350 is still open: on Windows, the code here causes it to link
   with PYTHON36.DLL (for example) instead of PYTHON3.DLL.  A fix was
   attempted in 164e526a5515 and 14ce6985e1c3, but reverted: virtualenv
   does not make PYTHON3.DLL available, and so the "correctly" compiled
   version would not run inside a virtualenv.  We will re-apply the fix
   after virtualenv has been fixed for some time.  For explanation, see
   issue #355.  For a workaround if you want PYTHON3.DLL and don't worry
   about virtualenv, see issue #350.  See also 'py_limited_api' in
   setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  include <pyconfig.h>
#  if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG)
#    define Py_LIMITED_API
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

#include "flexmotn_flat.h"

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, long, TnimcAxisConfigurationParameter, NIMC_DATA *)
/*  1 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9), // long
/*  2 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/*  3 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // TnimcAxisConfigurationParameter
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 536), // NIMC_DATA *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, long, TnimcCammingParameter, NIMC_DATA *)
/*  7 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/*  9 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // TnimcCammingParameter
/* 10 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, long, TnimcMotionIOExecution, NIMC_DATA *)
/* 13 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 14 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 15 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // TnimcMotionIOExecution
/* 16 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 18 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, long, TnimcMotionIOParameter, NIMC_DATA *)
/* 19 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 20 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 21 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // TnimcMotionIOParameter
/* 22 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 23 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 24 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, long, TnimcMoveConstraint, NIMC_DATA *)
/* 25 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 26 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 27 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // TnimcMoveConstraint
/* 28 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 29 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 30 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, long, long, double)
/* 31 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 32 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 33 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 34 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/* 35 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, long, unsigned short, double)
/* 37 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 38 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 39 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6), // unsigned short
/* 40 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(long, unsigned long, NIMC_CAMMING_ENABLE_DATA *)
/* 43 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 44 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10), // unsigned long
/* 45 */ _CFFI_OP(_CFFI_OP_POINTER, 535), // NIMC_CAMMING_ENABLE_DATA *
/* 46 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char)
/* 48 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 49 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 50 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, char *)
/* 51 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 52 */ _CFFI_OP(_CFFI_OP_POINTER, 95), // char *
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, char *, unsigned long *)
/* 55 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 56 */ _CFFI_OP(_CFFI_OP_NOOP, 52),
/* 57 */ _CFFI_OP(_CFFI_OP_POINTER, 44), // unsigned long *
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 59 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, double *)
/* 60 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 61 */ _CFFI_OP(_CFFI_OP_POINTER, 34), // double *
/* 62 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 63 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, long *)
/* 64 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 65 */ _CFFI_OP(_CFFI_OP_POINTER, 1), // long *
/* 66 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 67 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, long, unsigned char)
/* 68 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 69 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 70 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 71 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 72 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char)
/* 73 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 74 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 76 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, PID *, unsigned char)
/* 77 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 78 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 79 */ _CFFI_OP(_CFFI_OP_POINTER, 537), // PID *
/* 80 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 81 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, REGSTRY *)
/* 83 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 84 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 85 */ _CFFI_OP(_CFFI_OP_POINTER, 538), // REGSTRY *
/* 86 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, char *)
/* 88 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 89 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 90 */ _CFFI_OP(_CFFI_OP_NOOP, 52),
/* 91 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 92 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, char, unsigned char)
/* 93 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 94 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 95 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 96 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 97 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 98 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, double *)
/* 99 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 100 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 101 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 103 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, double, unsigned char)
/* 104 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 105 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 106 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 107 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 108 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, float, unsigned char)
/* 110 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 111 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 112 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 13), // float
/* 113 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, long *)
/* 116 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 117 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 118 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 119 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 120 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, long *, long *, long *)
/* 121 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 122 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 123 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 124 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 125 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 126 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 127 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, long, long, long, unsigned char)
/* 128 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 129 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 130 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 131 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 132 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 133 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 134 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 135 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, long, long, unsigned char)
/* 136 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 137 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 138 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 139 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 140 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 141 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 142 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, long, unsigned char)
/* 143 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 144 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 145 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 146 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 147 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 148 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, short *)
/* 149 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 150 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 151 */ _CFFI_OP(_CFFI_OP_POINTER, 156), // short *
/* 152 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 153 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, short, short, short, short, unsigned char)
/* 154 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 155 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 156 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5), // short
/* 157 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 158 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 159 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 160 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 161 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 162 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, short, short, unsigned char)
/* 163 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 164 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 165 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 166 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 167 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 168 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 169 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, short, unsigned char)
/* 170 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 171 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 172 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 173 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 174 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 175 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char)
/* 176 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 177 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 178 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 179 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 180 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned char *, unsigned short *, unsigned short *, unsigned char)
/* 181 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 182 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 183 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 184 */ _CFFI_OP(_CFFI_OP_POINTER, 48), // unsigned char *
/* 185 */ _CFFI_OP(_CFFI_OP_POINTER, 39), // unsigned short *
/* 186 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 187 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 188 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 189 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned char)
/* 190 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 191 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 192 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 193 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 194 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 195 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned char, unsigned char)
/* 196 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 197 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 198 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 199 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 200 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 201 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 202 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char)
/* 203 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 204 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 205 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 206 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 207 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 208 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 209 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 210 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned short)
/* 211 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 212 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 213 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 214 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 215 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 216 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned short, double *)
/* 217 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 218 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 219 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 220 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 221 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 222 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 223 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned short, double)
/* 224 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 225 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 226 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 227 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 228 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 229 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 230 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned char, unsigned short, long, unsigned long, unsigned short, double, double *)
/* 231 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 232 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 233 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 234 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 235 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 236 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 237 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 238 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 239 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 240 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 241 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned long *, unsigned short *, unsigned long *)
/* 242 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 243 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 244 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 245 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 246 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 247 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 248 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned long, double, double, double, double, unsigned char)
/* 249 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 250 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 251 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 252 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 253 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 254 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 255 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 256 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 257 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 258 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned long, double, double, long, unsigned char)
/* 259 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 260 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 261 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 262 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 263 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 264 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 265 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 266 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 267 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned long, double, double, unsigned char)
/* 268 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 269 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 270 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 271 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 272 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 273 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 274 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 275 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned long, long *)
/* 276 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 277 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 278 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 279 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 280 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 281 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned long, unsigned char)
/* 282 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 283 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 284 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 285 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 286 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 287 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned long, unsigned short, long *, unsigned char)
/* 288 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 289 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 290 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 291 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 292 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 293 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 294 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 295 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short *)
/* 296 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 297 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 298 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 299 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 300 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short)
/* 301 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 302 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 303 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 304 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 305 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, double *)
/* 306 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 307 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 308 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 309 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 310 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 311 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, double)
/* 312 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 313 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 314 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 315 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 316 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 317 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, double, unsigned char)
/* 318 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 319 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 320 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 321 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14),
/* 322 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 323 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 324 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, short)
/* 325 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 326 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 327 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 328 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 329 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 330 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, short, unsigned short, unsigned char)
/* 331 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 332 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 333 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 334 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5),
/* 335 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 336 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 337 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 338 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned char)
/* 339 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 340 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 341 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 342 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 343 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 344 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned long *)
/* 345 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 346 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 347 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 348 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 349 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 350 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned long)
/* 351 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 352 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 353 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 354 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 355 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 356 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned long, long, unsigned short *)
/* 357 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 358 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 359 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 360 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 361 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 362 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 363 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 364 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned long, unsigned char)
/* 365 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 366 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 367 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 368 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 369 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 370 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 371 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned long, unsigned long, unsigned short *)
/* 372 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 373 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 374 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 375 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 376 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 377 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 378 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 379 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short *)
/* 380 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 381 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 382 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 383 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 384 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 385 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short *, unsigned short *)
/* 386 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 387 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 388 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 389 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 390 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 391 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 392 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short)
/* 393 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 394 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 395 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 396 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 397 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 398 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short, unsigned char)
/* 399 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 400 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 401 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 402 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 403 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 404 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 405 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short, unsigned char, unsigned char)
/* 406 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 407 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 408 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 409 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 410 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 411 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 412 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 413 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short, unsigned short *)
/* 414 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 415 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 416 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 417 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 418 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 419 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 420 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short, unsigned short)
/* 421 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 422 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 423 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 424 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 425 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 426 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 427 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short, unsigned short, unsigned short)
/* 428 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 429 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 430 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 431 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 432 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 433 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 434 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 435 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short, unsigned short, unsigned short, unsigned short)
/* 436 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 437 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 438 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 439 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 440 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 441 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 442 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 443 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 444 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned char, unsigned short, unsigned short, unsigned short, unsigned short, unsigned short, unsigned short, unsigned char)
/* 445 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 446 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 447 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 448 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 449 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 450 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 451 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 452 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 453 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 454 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 455 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned long)
/* 456 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 457 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 458 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 459 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned long, char *, unsigned long *)
/* 460 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 461 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 462 */ _CFFI_OP(_CFFI_OP_NOOP, 52),
/* 463 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 464 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 465 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned long, unsigned long *)
/* 466 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 467 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 468 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 469 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 470 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short *)
/* 471 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 472 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 473 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 474 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short *, unsigned short *)
/* 475 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 476 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 477 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 478 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 479 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short *, unsigned short *, long *)
/* 480 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 481 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 482 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 483 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 484 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 485 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short *, unsigned short *, long *, unsigned short *, unsigned short *)
/* 486 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 487 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 488 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 489 */ _CFFI_OP(_CFFI_OP_NOOP, 65),
/* 490 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 491 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 492 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 493 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short *, unsigned short *, unsigned char *, unsigned short *, unsigned short *)
/* 494 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 495 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 496 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 497 */ _CFFI_OP(_CFFI_OP_NOOP, 184),
/* 498 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 499 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 500 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 501 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short)
/* 502 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 503 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 504 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 505 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short, unsigned char)
/* 506 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 507 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 508 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 509 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 510 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short, unsigned short *, unsigned short *)
/* 511 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 512 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 513 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 514 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 515 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 516 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short, unsigned short)
/* 517 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 518 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 519 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 520 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 521 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned char, unsigned short, unsigned short, unsigned short)
/* 522 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 523 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 524 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 525 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 526 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 527 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // long()(unsigned short, long, unsigned short, unsigned short, char *, unsigned long *)
/* 528 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 529 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9),
/* 530 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 531 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6),
/* 532 */ _CFFI_OP(_CFFI_OP_NOOP, 52),
/* 533 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 534 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 535 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // NIMC_CAMMING_ENABLE_DATA
/* 536 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // NIMC_DATA
/* 537 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // PID
/* 538 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // REGSTRY
};

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_NIMC_CAMMING_ENABLE_DATA(NIMC_CAMMING_ENABLE_DATA *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->axisIndex) | 0);  /* check that 'NIMC_CAMMING_ENABLE_DATA.axisIndex' is an integer */
  (void)((p->enable) | 0);  /* check that 'NIMC_CAMMING_ENABLE_DATA.enable' is an integer */
  { double *tmp = &p->position; (void)tmp; }
}
struct _cffi_align_typedef_NIMC_CAMMING_ENABLE_DATA { char x; NIMC_CAMMING_ENABLE_DATA y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_NIMC_DATA(NIMC_DATA *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->longData) | 0);  /* check that 'NIMC_DATA.longData' is an integer */
  (void)((p->boolData) | 0);  /* check that 'NIMC_DATA.boolData' is an integer */
  { double *tmp = &p->doubleData; (void)tmp; }
}
struct _cffi_align_typedef_NIMC_DATA { char x; NIMC_DATA y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_PID(PID *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->kp) | 0);  /* check that 'PID.kp' is an integer */
  (void)((p->ki) | 0);  /* check that 'PID.ki' is an integer */
  (void)((p->ilim) | 0);  /* check that 'PID.ilim' is an integer */
  (void)((p->kd) | 0);  /* check that 'PID.kd' is an integer */
  (void)((p->td) | 0);  /* check that 'PID.td' is an integer */
  (void)((p->kv) | 0);  /* check that 'PID.kv' is an integer */
  (void)((p->aff) | 0);  /* check that 'PID.aff' is an integer */
  (void)((p->vff) | 0);  /* check that 'PID.vff' is an integer */
}
struct _cffi_align_typedef_PID { char x; PID y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_REGSTRY(REGSTRY *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->device) | 0);  /* check that 'REGSTRY.device' is an integer */
  (void)((p->type) | 0);  /* check that 'REGSTRY.type' is an integer */
  (void)((p->pstart) | 0);  /* check that 'REGSTRY.pstart' is an integer */
  (void)((p->size) | 0);  /* check that 'REGSTRY.size' is an integer */
}
struct _cffi_align_typedef_REGSTRY { char x; REGSTRY y; };

static int _cffi_const_TnimcAxisConfigurationParameterEnable(unsigned long long *o)
{
  int n = (TnimcAxisConfigurationParameterEnable) <= 0;
  *o = (unsigned long long)((TnimcAxisConfigurationParameterEnable) | 0);  /* check that TnimcAxisConfigurationParameterEnable is an integer */
  return n;
}

static int _cffi_const_TnimcCammingParameterMasterCycle(unsigned long long *o)
{
  int n = (TnimcCammingParameterMasterCycle) <= 0;
  *o = (unsigned long long)((TnimcCammingParameterMasterCycle) | 0);  /* check that TnimcCammingParameterMasterCycle is an integer */
  return n;
}

static int _cffi_const_TnimcCammingParameterMasterOffset(unsigned long long *o)
{
  int n = (TnimcCammingParameterMasterOffset) <= 0;
  *o = (unsigned long long)((TnimcCammingParameterMasterOffset) | 0);  /* check that TnimcCammingParameterMasterOffset is an integer */
  return n;
}

static int _cffi_const_TnimcCammingParameterSlaveOffset(unsigned long long *o)
{
  int n = (TnimcCammingParameterSlaveOffset) <= 0;
  *o = (unsigned long long)((TnimcCammingParameterSlaveOffset) | 0);  /* check that TnimcCammingParameterSlaveOffset is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOExecutionForwardLimitStatus(unsigned long long *o)
{
  int n = (TnimcMotionIOExecutionForwardLimitStatus) <= 0;
  *o = (unsigned long long)((TnimcMotionIOExecutionForwardLimitStatus) | 0);  /* check that TnimcMotionIOExecutionForwardLimitStatus is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOExecutionReverseLimitStatus(unsigned long long *o)
{
  int n = (TnimcMotionIOExecutionReverseLimitStatus) <= 0;
  *o = (unsigned long long)((TnimcMotionIOExecutionReverseLimitStatus) | 0);  /* check that TnimcMotionIOExecutionReverseLimitStatus is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOExecutionForwardSoftwareLimitStatus(unsigned long long *o)
{
  int n = (TnimcMotionIOExecutionForwardSoftwareLimitStatus) <= 0;
  *o = (unsigned long long)((TnimcMotionIOExecutionForwardSoftwareLimitStatus) | 0);  /* check that TnimcMotionIOExecutionForwardSoftwareLimitStatus is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOExecutionReverseSoftwareLimitStatus(unsigned long long *o)
{
  int n = (TnimcMotionIOExecutionReverseSoftwareLimitStatus) <= 0;
  *o = (unsigned long long)((TnimcMotionIOExecutionReverseSoftwareLimitStatus) | 0);  /* check that TnimcMotionIOExecutionReverseSoftwareLimitStatus is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOExecutionHomeInputStatus(unsigned long long *o)
{
  int n = (TnimcMotionIOExecutionHomeInputStatus) <= 0;
  *o = (unsigned long long)((TnimcMotionIOExecutionHomeInputStatus) | 0);  /* check that TnimcMotionIOExecutionHomeInputStatus is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOExecutionInhibitInStatus(unsigned long long *o)
{
  int n = (TnimcMotionIOExecutionInhibitInStatus) <= 0;
  *o = (unsigned long long)((TnimcMotionIOExecutionInhibitInStatus) | 0);  /* check that TnimcMotionIOExecutionInhibitInStatus is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOExecutionInPositionStatus(unsigned long long *o)
{
  int n = (TnimcMotionIOExecutionInPositionStatus) <= 0;
  *o = (unsigned long long)((TnimcMotionIOExecutionInPositionStatus) | 0);  /* check that TnimcMotionIOExecutionInPositionStatus is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterForwardLimitEnable(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterForwardLimitEnable) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterForwardLimitEnable) | 0);  /* check that TnimcMotionIOParameterForwardLimitEnable is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterReverseLimitEnable(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterReverseLimitEnable) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterReverseLimitEnable) | 0);  /* check that TnimcMotionIOParameterReverseLimitEnable is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterForwardSoftwareLimitEnable(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterForwardSoftwareLimitEnable) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterForwardSoftwareLimitEnable) | 0);  /* check that TnimcMotionIOParameterForwardSoftwareLimitEnable is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterReverseSoftwareLimitEnable(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterReverseSoftwareLimitEnable) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterReverseSoftwareLimitEnable) | 0);  /* check that TnimcMotionIOParameterReverseSoftwareLimitEnable is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterHomeInputEnable(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterHomeInputEnable) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterHomeInputEnable) | 0);  /* check that TnimcMotionIOParameterHomeInputEnable is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterForwardLimitPolarity(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterForwardLimitPolarity) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterForwardLimitPolarity) | 0);  /* check that TnimcMotionIOParameterForwardLimitPolarity is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterReverseLimitPolarity(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterReverseLimitPolarity) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterReverseLimitPolarity) | 0);  /* check that TnimcMotionIOParameterReverseLimitPolarity is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterHomeInputPolarity(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterHomeInputPolarity) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterHomeInputPolarity) | 0);  /* check that TnimcMotionIOParameterHomeInputPolarity is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterForwardSoftwareLimitPosition(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterForwardSoftwareLimitPosition) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterForwardSoftwareLimitPosition) | 0);  /* check that TnimcMotionIOParameterForwardSoftwareLimitPosition is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterReverseSoftwareLimitPosition(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterReverseSoftwareLimitPosition) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterReverseSoftwareLimitPosition) | 0);  /* check that TnimcMotionIOParameterReverseSoftwareLimitPosition is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterInhibitInEnable(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterInhibitInEnable) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterInhibitInEnable) | 0);  /* check that TnimcMotionIOParameterInhibitInEnable is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterInhibitInPolarity(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterInhibitInPolarity) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterInhibitInPolarity) | 0);  /* check that TnimcMotionIOParameterInhibitInPolarity is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterInPositionEnable(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterInPositionEnable) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterInPositionEnable) | 0);  /* check that TnimcMotionIOParameterInPositionEnable is an integer */
  return n;
}

static int _cffi_const_TnimcMotionIOParameterInPositionPolarity(unsigned long long *o)
{
  int n = (TnimcMotionIOParameterInPositionPolarity) <= 0;
  *o = (unsigned long long)((TnimcMotionIOParameterInPositionPolarity) | 0);  /* check that TnimcMotionIOParameterInPositionPolarity is an integer */
  return n;
}

static int _cffi_const_TnimcMoveConstraintVelocity(unsigned long long *o)
{
  int n = (TnimcMoveConstraintVelocity) <= 0;
  *o = (unsigned long long)((TnimcMoveConstraintVelocity) | 0);  /* check that TnimcMoveConstraintVelocity is an integer */
  return n;
}

static int _cffi_const_TnimcMoveConstraintAcceleration(unsigned long long *o)
{
  int n = (TnimcMoveConstraintAcceleration) <= 0;
  *o = (unsigned long long)((TnimcMoveConstraintAcceleration) | 0);  /* check that TnimcMoveConstraintAcceleration is an integer */
  return n;
}

static int _cffi_const_TnimcMoveConstraintDeceleration(unsigned long long *o)
{
  int n = (TnimcMoveConstraintDeceleration) <= 0;
  *o = (unsigned long long)((TnimcMoveConstraintDeceleration) | 0);  /* check that TnimcMoveConstraintDeceleration is an integer */
  return n;
}

static int _cffi_const_TnimcMoveConstraintAccelerationJerk(unsigned long long *o)
{
  int n = (TnimcMoveConstraintAccelerationJerk) <= 0;
  *o = (unsigned long long)((TnimcMoveConstraintAccelerationJerk) | 0);  /* check that TnimcMoveConstraintAccelerationJerk is an integer */
  return n;
}

static int _cffi_const_TnimcMoveConstraintDecelerationJerk(unsigned long long *o)
{
  int n = (TnimcMoveConstraintDecelerationJerk) <= 0;
  *o = (unsigned long long)((TnimcMoveConstraintDecelerationJerk) | 0);  /* check that TnimcMoveConstraintDecelerationJerk is an integer */
  return n;
}

static long _cffi_d_flex_acquire_trajectory_data(unsigned char x0, unsigned short x1, unsigned short x2, unsigned short x3)
{
  return flex_acquire_trajectory_data(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_acquire_trajectory_data(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned short x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_acquire_trajectory_data", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_acquire_trajectory_data(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_acquire_trajectory_data _cffi_d_flex_acquire_trajectory_data
#endif

static long _cffi_d_flex_add_vars(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3)
{
  return flex_add_vars(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_add_vars(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_add_vars", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_add_vars(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_add_vars _cffi_d_flex_add_vars
#endif

static long _cffi_d_flex_and_vars(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3)
{
  return flex_and_vars(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_and_vars(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_and_vars", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_and_vars(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_and_vars _cffi_d_flex_and_vars
#endif

static long _cffi_d_flex_begin_store(unsigned char x0, unsigned char x1)
{
  return flex_begin_store(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_begin_store(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_begin_store", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_begin_store(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_begin_store _cffi_d_flex_begin_store
#endif

static long _cffi_d_flex_blend(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_blend(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_blend(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_blend", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_blend(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_blend _cffi_d_flex_blend
#endif

static long _cffi_d_flex_check_blend_complete_status(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short * x3)
{
  return flex_check_blend_complete_status(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_check_blend_complete_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_check_blend_complete_status", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_check_blend_complete_status(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_check_blend_complete_status _cffi_d_flex_check_blend_complete_status
#endif

static long _cffi_d_flex_check_buffer(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_check_buffer(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_check_buffer(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_check_buffer", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_check_buffer(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_check_buffer _cffi_d_flex_check_buffer
#endif

static long _cffi_d_flex_check_buffer_rtn(unsigned char x0, unsigned char x1, unsigned long * x2, unsigned short * x3, unsigned long * x4)
{
  return flex_check_buffer_rtn(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_check_buffer_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long * x2;
  unsigned short * x3;
  unsigned long * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_check_buffer_rtn", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_check_buffer_rtn(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_check_buffer_rtn _cffi_d_flex_check_buffer_rtn
#endif

static long _cffi_d_flex_check_move_complete_status(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short * x3)
{
  return flex_check_move_complete_status(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_check_move_complete_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_check_move_complete_status", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_check_move_complete_status(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_check_move_complete_status _cffi_d_flex_check_move_complete_status
#endif

static long _cffi_d_flex_check_reference(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short * x3, unsigned short * x4)
{
  return flex_check_reference(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_check_reference(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short * x3;
  unsigned short * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_check_reference", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_check_reference(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_check_reference _cffi_d_flex_check_reference
#endif

static long _cffi_d_flex_clear_buffer(unsigned char x0, unsigned char x1)
{
  return flex_clear_buffer(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_clear_buffer(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_clear_buffer", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_clear_buffer(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_clear_buffer _cffi_d_flex_clear_buffer
#endif

static long _cffi_d_flex_clear_pu_status(unsigned char x0)
{
  return flex_clear_pu_status(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_clear_pu_status(PyObject *self, PyObject *arg0)
{
  unsigned char x0;
  long result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_clear_pu_status(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_clear_pu_status _cffi_d_flex_clear_pu_status
#endif

static long _cffi_d_flex_communicate(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char * x3, unsigned short * x4, unsigned short * x5, unsigned char x6)
{
  return flex_communicate(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_communicate(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char * x3;
  unsigned short * x4;
  unsigned short * x5;
  unsigned char x6;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "flex_communicate", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(184), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(184), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x6 = _cffi_to_c_int(arg6, unsigned char);
  if (x6 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_communicate(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_communicate _cffi_d_flex_communicate
#endif

static long _cffi_d_flex_config_axis(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3, unsigned char x4, unsigned char x5)
{
  return flex_config_axis(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_config_axis(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  unsigned char x4;
  unsigned char x5;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_config_axis", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned char);
  if (x5 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_config_axis(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_config_axis _cffi_d_flex_config_axis
#endif

static long _cffi_d_flex_config_gear_master(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_config_gear_master(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_config_gear_master(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_config_gear_master", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_config_gear_master(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_config_gear_master _cffi_d_flex_config_gear_master
#endif

static long _cffi_d_flex_config_inhibit_output(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned short x4)
{
  return flex_config_inhibit_output(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_config_inhibit_output(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned short x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_config_inhibit_output", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned short);
  if (x4 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_config_inhibit_output(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_config_inhibit_output _cffi_d_flex_config_inhibit_output
#endif

static long _cffi_d_flex_config_mc_criteria(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned char x4, unsigned char x5)
{
  return flex_config_mc_criteria(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_config_mc_criteria(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned char x4;
  unsigned char x5;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_config_mc_criteria", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned char);
  if (x5 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_config_mc_criteria(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_config_mc_criteria _cffi_d_flex_config_mc_criteria
#endif

static long _cffi_d_flex_config_vect_spc(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3, unsigned char x4)
{
  return flex_config_vect_spc(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_config_vect_spc(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_config_vect_spc", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_config_vect_spc(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_config_vect_spc _cffi_d_flex_config_vect_spc
#endif

static long _cffi_d_flex_configure_breakpoint(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned short x4)
{
  return flex_configure_breakpoint(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_breakpoint(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned short x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_configure_breakpoint", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned short);
  if (x4 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_breakpoint(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_breakpoint _cffi_d_flex_configure_breakpoint
#endif

static long _cffi_d_flex_configure_breakpoint_output(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3)
{
  return flex_configure_breakpoint_output(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_breakpoint_output(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_configure_breakpoint_output", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_breakpoint_output(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_breakpoint_output _cffi_d_flex_configure_breakpoint_output
#endif

static long _cffi_d_flex_configure_buffer(unsigned char x0, unsigned char x1, unsigned char x2, unsigned short x3, long x4, unsigned long x5, unsigned short x6, double x7, double * x8)
{
  return flex_configure_buffer(x0, x1, x2, x3, x4, x5, x6, x7, x8);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_buffer(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned short x3;
  long x4;
  unsigned long x5;
  unsigned short x6;
  double x7;
  double * x8;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;
  PyObject *arg8;

  if (!PyArg_UnpackTuple(args, "flex_configure_buffer", 9, 9, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7, &arg8))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, long);
  if (x4 == (long)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned long);
  if (x5 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, unsigned short);
  if (x6 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x7 = (double)_cffi_to_c_double(arg7);
  if (x7 == (double)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg8, (char **)&x8);
  if (datasize != 0) {
    x8 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(61), arg8, (char **)&x8,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_buffer(x0, x1, x2, x3, x4, x5, x6, x7, x8); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_buffer _cffi_d_flex_configure_buffer
#endif

static long _cffi_d_flex_configure_camming_master(long x0, long x1, long x2, double x3)
{
  return flex_configure_camming_master(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_camming_master(PyObject *self, PyObject *args)
{
  long x0;
  long x1;
  long x2;
  double x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_configure_camming_master", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_camming_master(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_camming_master _cffi_d_flex_configure_camming_master
#endif

static long _cffi_d_flex_configure_drive_signal(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned short x4, unsigned short x5)
{
  return flex_configure_drive_signal(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_drive_signal(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned short x4;
  unsigned short x5;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_configure_drive_signal", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned short);
  if (x4 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned short);
  if (x5 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_drive_signal(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_drive_signal _cffi_d_flex_configure_drive_signal
#endif

static long _cffi_d_flex_configure_encoder_filter(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_configure_encoder_filter(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_encoder_filter(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_configure_encoder_filter", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_encoder_filter(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_encoder_filter _cffi_d_flex_configure_encoder_filter
#endif

static long _cffi_d_flex_configure_encoder_polarity(unsigned char x0, unsigned short x1, unsigned short x2, unsigned short x3)
{
  return flex_configure_encoder_polarity(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_encoder_polarity(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned short x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_configure_encoder_polarity", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_encoder_polarity(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_encoder_polarity _cffi_d_flex_configure_encoder_polarity
#endif

static long _cffi_d_flex_configure_hs_capture(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3)
{
  return flex_configure_hs_capture(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_hs_capture(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_configure_hs_capture", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_hs_capture(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_hs_capture _cffi_d_flex_configure_hs_capture
#endif

static long _cffi_d_flex_configure_pwm_output(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3)
{
  return flex_configure_pwm_output(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_pwm_output(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_configure_pwm_output", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_pwm_output(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_pwm_output _cffi_d_flex_configure_pwm_output
#endif

static long _cffi_d_flex_configure_stepper_output(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned short x4)
{
  return flex_configure_stepper_output(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_configure_stepper_output(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned short x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_configure_stepper_output", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned short);
  if (x4 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_configure_stepper_output(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_configure_stepper_output _cffi_d_flex_configure_stepper_output
#endif

static long _cffi_d_flex_div_vars(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3)
{
  return flex_div_vars(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_div_vars(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_div_vars", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_div_vars(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_div_vars _cffi_d_flex_div_vars
#endif

static long _cffi_d_flex_enable_1394_watchdog(unsigned char x0, unsigned short x1)
{
  return flex_enable_1394_watchdog(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_1394_watchdog(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_enable_1394_watchdog", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_1394_watchdog(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_1394_watchdog _cffi_d_flex_enable_1394_watchdog
#endif

static long _cffi_d_flex_enable_adcs(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_enable_adcs(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_adcs(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_enable_adcs", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_adcs(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_adcs _cffi_d_flex_enable_adcs
#endif

static long _cffi_d_flex_enable_auto_start(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_enable_auto_start(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_auto_start(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_enable_auto_start", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_auto_start(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_auto_start _cffi_d_flex_enable_auto_start
#endif

static long _cffi_d_flex_enable_axis(unsigned char x0, unsigned char x1, unsigned char x2, unsigned short x3)
{
  return flex_enable_axis(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_axis(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_enable_axis", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_axis(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_axis _cffi_d_flex_enable_axis
#endif

static long _cffi_d_flex_enable_axis_limit(unsigned char x0, unsigned short x1, unsigned short x2, unsigned short x3)
{
  return flex_enable_axis_limit(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_axis_limit(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned short x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_enable_axis_limit", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_axis_limit(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_axis_limit _cffi_d_flex_enable_axis_limit
#endif

static long _cffi_d_flex_enable_breakpoint(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_enable_breakpoint(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_breakpoint(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_enable_breakpoint", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_breakpoint(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_breakpoint _cffi_d_flex_enable_breakpoint
#endif

static long _cffi_d_flex_enable_camming(long x0, unsigned long x1, NIMC_CAMMING_ENABLE_DATA * x2)
{
  return flex_enable_camming(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_camming(PyObject *self, PyObject *args)
{
  long x0;
  unsigned long x1;
  NIMC_CAMMING_ENABLE_DATA * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_enable_camming", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (NIMC_CAMMING_ENABLE_DATA *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_camming(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_camming _cffi_d_flex_enable_camming
#endif

static long _cffi_d_flex_enable_camming_single_axis(long x0, long x1, unsigned short x2, double x3)
{
  return flex_enable_camming_single_axis(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_camming_single_axis(PyObject *self, PyObject *args)
{
  long x0;
  long x1;
  unsigned short x2;
  double x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_enable_camming_single_axis", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_camming_single_axis(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_camming_single_axis _cffi_d_flex_enable_camming_single_axis
#endif

static long _cffi_d_flex_enable_encoders(unsigned char x0, unsigned short x1)
{
  return flex_enable_encoders(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_encoders(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_enable_encoders", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_encoders(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_encoders _cffi_d_flex_enable_encoders
#endif

static long _cffi_d_flex_enable_gearing(unsigned char x0, unsigned short x1)
{
  return flex_enable_gearing(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_gearing(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_enable_gearing", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_gearing(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_gearing _cffi_d_flex_enable_gearing
#endif

static long _cffi_d_flex_enable_gearing_single_axis(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_enable_gearing_single_axis(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_gearing_single_axis(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_enable_gearing_single_axis", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_gearing_single_axis(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_gearing_single_axis _cffi_d_flex_enable_gearing_single_axis
#endif

static long _cffi_d_flex_enable_home_inputs(unsigned char x0, unsigned short x1)
{
  return flex_enable_home_inputs(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_home_inputs(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_enable_home_inputs", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_home_inputs(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_home_inputs _cffi_d_flex_enable_home_inputs
#endif

static long _cffi_d_flex_enable_hs_capture(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_enable_hs_capture(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_hs_capture(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_enable_hs_capture", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_hs_capture(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_hs_capture _cffi_d_flex_enable_hs_capture
#endif

static long _cffi_d_flex_enable_shutdown(unsigned char x0)
{
  return flex_enable_shutdown(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_enable_shutdown(PyObject *self, PyObject *arg0)
{
  unsigned char x0;
  long result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_enable_shutdown(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_enable_shutdown _cffi_d_flex_enable_shutdown
#endif

static long _cffi_d_flex_end_store(unsigned char x0, unsigned char x1)
{
  return flex_end_store(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_end_store(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_end_store", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_end_store(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_end_store _cffi_d_flex_end_store
#endif

static long _cffi_d_flex_find_home(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_find_home(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_find_home(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_find_home", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_find_home(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_find_home _cffi_d_flex_find_home
#endif

static long _cffi_d_flex_find_index(unsigned char x0, unsigned char x1, unsigned short x2, short x3)
{
  return flex_find_index(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_find_index(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_find_index", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, short);
  if (x3 == (short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_find_index(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_find_index _cffi_d_flex_find_index
#endif

static long _cffi_d_flex_find_reference(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_find_reference(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_find_reference(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_find_reference", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_find_reference(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_find_reference _cffi_d_flex_find_reference
#endif

static long _cffi_d_flex_flush_rdb(unsigned char x0)
{
  return flex_flush_rdb(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_flush_rdb(PyObject *self, PyObject *arg0)
{
  unsigned char x0;
  long result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_flush_rdb(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_flush_rdb _cffi_d_flex_flush_rdb
#endif

static long _cffi_d_flex_get_error_description(unsigned short x0, long x1, unsigned short x2, unsigned short x3, char * x4, unsigned long * x5)
{
  return flex_get_error_description(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_get_error_description(PyObject *self, PyObject *args)
{
  unsigned short x0;
  long x1;
  unsigned short x2;
  unsigned short x3;
  char * x4;
  unsigned long * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_get_error_description", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned short);
  if (x0 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(52), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(52), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_get_error_description(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_get_error_description _cffi_d_flex_get_error_description
#endif

static long _cffi_d_flex_get_last_error(unsigned char x0, unsigned short * x1, unsigned short * x2, long * x3)
{
  return flex_get_last_error(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_get_last_error(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  unsigned short * x2;
  long * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_get_last_error", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_get_last_error(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_get_last_error _cffi_d_flex_get_last_error
#endif

static long _cffi_d_flex_get_motion_board_info(unsigned char x0, unsigned long x1, unsigned long * x2)
{
  return flex_get_motion_board_info(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_get_motion_board_info(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned long x1;
  unsigned long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_get_motion_board_info", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_get_motion_board_info(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_get_motion_board_info _cffi_d_flex_get_motion_board_info
#endif

static long _cffi_d_flex_get_motion_board_info_string(unsigned char x0, unsigned long x1, char * x2, unsigned long * x3)
{
  return flex_get_motion_board_info_string(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_get_motion_board_info_string(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned long x1;
  char * x2;
  unsigned long * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_get_motion_board_info_string", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(52), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(52), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_get_motion_board_info_string(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_get_motion_board_info_string _cffi_d_flex_get_motion_board_info_string
#endif

static long _cffi_d_flex_get_motion_board_name(unsigned char x0, char * x1, unsigned long * x2)
{
  return flex_get_motion_board_name(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_get_motion_board_name(PyObject *self, PyObject *args)
{
  unsigned char x0;
  char * x1;
  unsigned long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_get_motion_board_name", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(52), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(52), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_get_motion_board_name(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_get_motion_board_name _cffi_d_flex_get_motion_board_name
#endif

static long _cffi_d_flex_get_reference_parameter(unsigned char x0, unsigned char x1, unsigned char x2, unsigned short x3, double * x4)
{
  return flex_get_reference_parameter(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_get_reference_parameter(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned short x3;
  double * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_get_reference_parameter", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(61), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_get_reference_parameter(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_get_reference_parameter _cffi_d_flex_get_reference_parameter
#endif

static long _cffi_d_flex_getf64(unsigned char x0, unsigned char x1, unsigned short x2, double * x3)
{
  return flex_getf64(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_getf64(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  double * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_getf64", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(61), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_getf64(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_getf64 _cffi_d_flex_getf64
#endif

static long _cffi_d_flex_getu32(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long * x3)
{
  return flex_getu32(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_getu32(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_getu32", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_getu32(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_getu32 _cffi_d_flex_getu32
#endif

static long _cffi_d_flex_initialize_controller(unsigned char x0, char * x1)
{
  return flex_initialize_controller(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_initialize_controller(PyObject *self, PyObject *args)
{
  unsigned char x0;
  char * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_initialize_controller", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(52), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(52), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_initialize_controller(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_initialize_controller _cffi_d_flex_initialize_controller
#endif

static long _cffi_d_flex_insert_program_label(unsigned char x0, unsigned short x1)
{
  return flex_insert_program_label(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_insert_program_label(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_insert_program_label", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_insert_program_label(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_insert_program_label _cffi_d_flex_insert_program_label
#endif

static long _cffi_d_flex_jump_on_event(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned short x4, unsigned short x5, unsigned short x6)
{
  return flex_jump_on_event(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_jump_on_event(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned short x4;
  unsigned short x5;
  unsigned short x6;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "flex_jump_on_event", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned short);
  if (x4 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned short);
  if (x5 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, unsigned short);
  if (x6 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_jump_on_event(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_jump_on_event _cffi_d_flex_jump_on_event
#endif

static long _cffi_d_flex_load_acceleration(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long x3, unsigned char x4)
{
  return flex_load_acceleration(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_acceleration(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_acceleration", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned long);
  if (x3 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_acceleration(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_acceleration _cffi_d_flex_load_acceleration
#endif

static long _cffi_d_flex_load_advanced_control_parameter(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long x3, unsigned char x4)
{
  return flex_load_advanced_control_parameter(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_advanced_control_parameter(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_advanced_control_parameter", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned long);
  if (x3 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_advanced_control_parameter(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_advanced_control_parameter _cffi_d_flex_load_advanced_control_parameter
#endif

static long _cffi_d_flex_load_axis_configuration_parameter(long x0, long x1, TnimcAxisConfigurationParameter x2, NIMC_DATA * x3)
{
  return flex_load_axis_configuration_parameter(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_axis_configuration_parameter(PyObject *self, PyObject *args)
{
  long x0;
  long x1;
  TnimcAxisConfigurationParameter x2;
  NIMC_DATA * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_axis_configuration_parameter", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(3), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (NIMC_DATA *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_axis_configuration_parameter(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_axis_configuration_parameter _cffi_d_flex_load_axis_configuration_parameter
#endif

static long _cffi_d_flex_load_base_vel(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_load_base_vel(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_base_vel(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_base_vel", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_base_vel(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_base_vel _cffi_d_flex_load_base_vel
#endif

static long _cffi_d_flex_load_blend_fact(unsigned char x0, unsigned char x1, short x2, unsigned char x3)
{
  return flex_load_blend_fact(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_blend_fact(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_blend_fact", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, short);
  if (x2 == (short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_blend_fact(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_blend_fact _cffi_d_flex_load_blend_fact
#endif

static long _cffi_d_flex_load_bp_modulus(unsigned char x0, unsigned char x1, unsigned long x2, unsigned char x3)
{
  return flex_load_bp_modulus(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_bp_modulus(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_bp_modulus", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_bp_modulus(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_bp_modulus _cffi_d_flex_load_bp_modulus
#endif

static long _cffi_d_flex_load_camming_parameter(long x0, long x1, TnimcCammingParameter x2, NIMC_DATA * x3)
{
  return flex_load_camming_parameter(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_camming_parameter(PyObject *self, PyObject *args)
{
  long x0;
  long x1;
  TnimcCammingParameter x2;
  NIMC_DATA * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_camming_parameter", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(9), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (NIMC_DATA *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_camming_parameter(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_camming_parameter _cffi_d_flex_load_camming_parameter
#endif

static long _cffi_d_flex_load_circular_arc(unsigned char x0, unsigned char x1, unsigned long x2, double x3, double x4, unsigned char x5)
{
  return flex_load_circular_arc(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_circular_arc(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  double x3;
  double x4;
  unsigned char x5;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_load_circular_arc", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned char);
  if (x5 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_circular_arc(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_circular_arc _cffi_d_flex_load_circular_arc
#endif

static long _cffi_d_flex_load_commutation_parameter(unsigned char x0, unsigned char x1, unsigned short x2, double x3)
{
  return flex_load_commutation_parameter(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_commutation_parameter(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  double x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_commutation_parameter", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_commutation_parameter(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_commutation_parameter _cffi_d_flex_load_commutation_parameter
#endif

static long _cffi_d_flex_load_counts_steps_rev(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long x3)
{
  return flex_load_counts_steps_rev(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_counts_steps_rev(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_counts_steps_rev", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned long);
  if (x3 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_counts_steps_rev(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_counts_steps_rev _cffi_d_flex_load_counts_steps_rev
#endif

static long _cffi_d_flex_load_dac(unsigned char x0, unsigned char x1, short x2, unsigned char x3)
{
  return flex_load_dac(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_dac(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_dac", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, short);
  if (x2 == (short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_dac(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_dac _cffi_d_flex_load_dac
#endif

static long _cffi_d_flex_load_delay(unsigned char x0, unsigned long x1)
{
  return flex_load_delay(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_delay(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned long x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_load_delay", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_delay(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_delay _cffi_d_flex_load_delay
#endif

static long _cffi_d_flex_load_description(unsigned char x0, unsigned char x1, char * x2)
{
  return flex_load_description(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_description(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  char * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_load_description", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(52), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(52), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_description(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_description _cffi_d_flex_load_description
#endif

static long _cffi_d_flex_load_follow_err(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_load_follow_err(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_follow_err(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_follow_err", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_follow_err(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_follow_err _cffi_d_flex_load_follow_err
#endif

static long _cffi_d_flex_load_gear_ratio(unsigned char x0, unsigned char x1, unsigned short x2, short x3, unsigned short x4, unsigned char x5)
{
  return flex_load_gear_ratio(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_gear_ratio(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  short x3;
  unsigned short x4;
  unsigned char x5;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_load_gear_ratio", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, short);
  if (x3 == (short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned short);
  if (x4 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned char);
  if (x5 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_gear_ratio(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_gear_ratio _cffi_d_flex_load_gear_ratio
#endif

static long _cffi_d_flex_load_helical_arc(unsigned char x0, unsigned char x1, unsigned long x2, double x3, double x4, long x5, unsigned char x6)
{
  return flex_load_helical_arc(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_helical_arc(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  double x3;
  double x4;
  long x5;
  unsigned char x6;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "flex_load_helical_arc", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, long);
  if (x5 == (long)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, unsigned char);
  if (x6 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_helical_arc(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_helical_arc _cffi_d_flex_load_helical_arc
#endif

static long _cffi_d_flex_load_motion_io_parameter(long x0, long x1, TnimcMotionIOParameter x2, NIMC_DATA * x3)
{
  return flex_load_motion_io_parameter(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_motion_io_parameter(PyObject *self, PyObject *args)
{
  long x0;
  long x1;
  TnimcMotionIOParameter x2;
  NIMC_DATA * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_motion_io_parameter", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(21), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (NIMC_DATA *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_motion_io_parameter(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_motion_io_parameter _cffi_d_flex_load_motion_io_parameter
#endif

static long _cffi_d_flex_load_move_constraint(long x0, long x1, TnimcMoveConstraint x2, NIMC_DATA * x3)
{
  return flex_load_move_constraint(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_move_constraint(PyObject *self, PyObject *args)
{
  long x0;
  long x1;
  TnimcMoveConstraint x2;
  NIMC_DATA * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_move_constraint", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(27), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (NIMC_DATA *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_move_constraint(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_move_constraint _cffi_d_flex_load_move_constraint
#endif

static long _cffi_d_flex_load_pid_parameters(unsigned char x0, unsigned char x1, PID * x2, unsigned char x3)
{
  return flex_load_pid_parameters(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_pid_parameters(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  PID * x2;
  unsigned char x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_pid_parameters", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(79), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (PID *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(79), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_pid_parameters(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_pid_parameters _cffi_d_flex_load_pid_parameters
#endif

static long _cffi_d_flex_load_pos_bp(unsigned char x0, unsigned char x1, long x2, unsigned char x3)
{
  return flex_load_pos_bp(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_pos_bp(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_pos_bp", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_pos_bp(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_pos_bp _cffi_d_flex_load_pos_bp
#endif

static long _cffi_d_flex_load_pos_modulus(unsigned char x0, unsigned char x1, unsigned long x2, unsigned char x3)
{
  return flex_load_pos_modulus(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_pos_modulus(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_pos_modulus", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_pos_modulus(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_pos_modulus _cffi_d_flex_load_pos_modulus
#endif

static long _cffi_d_flex_load_program_time_slice(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_load_program_time_slice(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_program_time_slice(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_program_time_slice", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_program_time_slice(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_program_time_slice _cffi_d_flex_load_program_time_slice
#endif

static long _cffi_d_flex_load_pwm_duty(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_load_pwm_duty(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_pwm_duty(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_pwm_duty", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_pwm_duty(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_pwm_duty _cffi_d_flex_load_pwm_duty
#endif

static long _cffi_d_flex_load_reference_parameter(unsigned char x0, unsigned char x1, unsigned char x2, unsigned short x3, double x4)
{
  return flex_load_reference_parameter(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_reference_parameter(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned short x3;
  double x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_reference_parameter", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_reference_parameter(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_reference_parameter _cffi_d_flex_load_reference_parameter
#endif

static long _cffi_d_flex_load_rpm(unsigned char x0, unsigned char x1, double x2, unsigned char x3)
{
  return flex_load_rpm(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_rpm(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  double x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_rpm", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_rpm(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_rpm _cffi_d_flex_load_rpm
#endif

static long _cffi_d_flex_load_rpm_thresh(unsigned char x0, unsigned char x1, double x2, unsigned char x3)
{
  return flex_load_rpm_thresh(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_rpm_thresh(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  double x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_rpm_thresh", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = (double)_cffi_to_c_double(arg2);
  if (x2 == (double)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_rpm_thresh(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_rpm_thresh _cffi_d_flex_load_rpm_thresh
#endif

static long _cffi_d_flex_load_rpsps(unsigned char x0, unsigned char x1, unsigned short x2, double x3, unsigned char x4)
{
  return flex_load_rpsps(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_rpsps(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  double x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_rpsps", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_rpsps(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_rpsps _cffi_d_flex_load_rpsps
#endif

static long _cffi_d_flex_load_run_stop_threshold(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_load_run_stop_threshold(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_run_stop_threshold(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_run_stop_threshold", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_run_stop_threshold(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_run_stop_threshold _cffi_d_flex_load_run_stop_threshold
#endif

static long _cffi_d_flex_load_scurve_time(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_load_scurve_time(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_scurve_time(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_scurve_time", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_scurve_time(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_scurve_time _cffi_d_flex_load_scurve_time
#endif

static long _cffi_d_flex_load_single_pid_parameter(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned char x4)
{
  return flex_load_single_pid_parameter(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_single_pid_parameter(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_single_pid_parameter", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_single_pid_parameter(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_single_pid_parameter _cffi_d_flex_load_single_pid_parameter
#endif

static long _cffi_d_flex_load_spherical_arc(unsigned char x0, unsigned char x1, unsigned long x2, double x3, double x4, double x5, double x6, unsigned char x7)
{
  return flex_load_spherical_arc(x0, x1, x2, x3, x4, x5, x6, x7);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_spherical_arc(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  double x3;
  double x4;
  double x5;
  double x6;
  unsigned char x7;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;

  if (!PyArg_UnpackTuple(args, "flex_load_spherical_arc", 8, 8, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  x4 = (double)_cffi_to_c_double(arg4);
  if (x4 == (double)-1 && PyErr_Occurred())
    return NULL;

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  x6 = (double)_cffi_to_c_double(arg6);
  if (x6 == (double)-1 && PyErr_Occurred())
    return NULL;

  x7 = _cffi_to_c_int(arg7, unsigned char);
  if (x7 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_spherical_arc(x0, x1, x2, x3, x4, x5, x6, x7); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_spherical_arc _cffi_d_flex_load_spherical_arc
#endif

static long _cffi_d_flex_load_sw_lim_pos(unsigned char x0, unsigned char x1, long x2, long x3, unsigned char x4)
{
  return flex_load_sw_lim_pos(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_sw_lim_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long x2;
  long x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_sw_lim_pos", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, long);
  if (x3 == (long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_sw_lim_pos(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_sw_lim_pos _cffi_d_flex_load_sw_lim_pos
#endif

static long _cffi_d_flex_load_target_pos(unsigned char x0, unsigned char x1, long x2, unsigned char x3)
{
  return flex_load_target_pos(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_target_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_target_pos", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_target_pos(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_target_pos _cffi_d_flex_load_target_pos
#endif

static long _cffi_d_flex_load_torque_lim(unsigned char x0, unsigned char x1, short x2, short x3, short x4, short x5, unsigned char x6)
{
  return flex_load_torque_lim(x0, x1, x2, x3, x4, x5, x6);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_torque_lim(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  short x2;
  short x3;
  short x4;
  short x5;
  unsigned char x6;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;

  if (!PyArg_UnpackTuple(args, "flex_load_torque_lim", 7, 7, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, short);
  if (x2 == (short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, short);
  if (x3 == (short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, short);
  if (x4 == (short)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, short);
  if (x5 == (short)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, unsigned char);
  if (x6 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_torque_lim(x0, x1, x2, x3, x4, x5, x6); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_torque_lim _cffi_d_flex_load_torque_lim
#endif

static long _cffi_d_flex_load_torque_offset(unsigned char x0, unsigned char x1, short x2, short x3, unsigned char x4)
{
  return flex_load_torque_offset(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_torque_offset(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  short x2;
  short x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_torque_offset", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, short);
  if (x2 == (short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, short);
  if (x3 == (short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_torque_offset(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_torque_offset _cffi_d_flex_load_torque_offset
#endif

static long _cffi_d_flex_load_var(unsigned char x0, long x1, unsigned char x2)
{
  return flex_load_var(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_var(PyObject *self, PyObject *args)
{
  unsigned char x0;
  long x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_load_var", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_var(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_var _cffi_d_flex_load_var
#endif

static long _cffi_d_flex_load_velocity(unsigned char x0, unsigned char x1, long x2, unsigned char x3)
{
  return flex_load_velocity(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_velocity(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_velocity", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_velocity(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_velocity _cffi_d_flex_load_velocity
#endif

static long _cffi_d_flex_load_velocity_filter_parameter(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned char x4)
{
  return flex_load_velocity_filter_parameter(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_velocity_filter_parameter(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_load_velocity_filter_parameter", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_velocity_filter_parameter(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_velocity_filter_parameter _cffi_d_flex_load_velocity_filter_parameter
#endif

static long _cffi_d_flex_load_velocity_override(unsigned char x0, unsigned char x1, float x2, unsigned char x3)
{
  return flex_load_velocity_override(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_velocity_override(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  float x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_velocity_override", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = (float)_cffi_to_c_float(arg2);
  if (x2 == (float)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_velocity_override(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_velocity_override _cffi_d_flex_load_velocity_override
#endif

static long _cffi_d_flex_load_velocity_threshold(unsigned char x0, unsigned char x1, unsigned long x2, unsigned char x3)
{
  return flex_load_velocity_threshold(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_velocity_threshold(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_load_velocity_threshold", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_velocity_threshold(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_velocity_threshold _cffi_d_flex_load_velocity_threshold
#endif

static long _cffi_d_flex_load_vs_pos(unsigned char x0, unsigned char x1, long x2, long x3, long x4, unsigned char x5)
{
  return flex_load_vs_pos(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_load_vs_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long x2;
  long x3;
  long x4;
  unsigned char x5;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_load_vs_pos", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, long);
  if (x3 == (long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, long);
  if (x4 == (long)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned char);
  if (x5 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_load_vs_pos(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_load_vs_pos _cffi_d_flex_load_vs_pos
#endif

static long _cffi_d_flex_lshift_var(unsigned char x0, unsigned char x1, char x2, unsigned char x3)
{
  return flex_lshift_var(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_lshift_var(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_lshift_var", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = (char)_cffi_to_c_char(arg2);
  if (x2 == (char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_lshift_var(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_lshift_var _cffi_d_flex_lshift_var
#endif

static long _cffi_d_flex_mult_vars(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3)
{
  return flex_mult_vars(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_mult_vars(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_mult_vars", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_mult_vars(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_mult_vars _cffi_d_flex_mult_vars
#endif

static long _cffi_d_flex_not_var(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_not_var(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_not_var(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_not_var", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_not_var(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_not_var _cffi_d_flex_not_var
#endif

static long _cffi_d_flex_object_mem_manage(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_object_mem_manage(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_object_mem_manage(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_object_mem_manage", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_object_mem_manage(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_object_mem_manage _cffi_d_flex_object_mem_manage
#endif

static long _cffi_d_flex_or_vars(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3)
{
  return flex_or_vars(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_or_vars(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_or_vars", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_or_vars(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_or_vars _cffi_d_flex_or_vars
#endif

static long _cffi_d_flex_pause_prog(unsigned char x0, unsigned char x1)
{
  return flex_pause_prog(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_pause_prog(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_pause_prog", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_pause_prog(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_pause_prog _cffi_d_flex_pause_prog
#endif

static long _cffi_d_flex_read_adc16(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_adc16(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_adc16(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_adc16", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_adc16(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_adc16 _cffi_d_flex_read_adc16
#endif

static long _cffi_d_flex_read_adc16_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_adc16_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_adc16_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_adc16_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_adc16_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_adc16_rtn _cffi_d_flex_read_adc16_rtn
#endif

static long _cffi_d_flex_read_axis_limit_status(unsigned char x0, unsigned short x1, unsigned char x2)
{
  return flex_read_axis_limit_status(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_axis_limit_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_axis_limit_status", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_axis_limit_status(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_axis_limit_status _cffi_d_flex_read_axis_limit_status
#endif

static long _cffi_d_flex_read_axis_limit_status_rtn(unsigned char x0, unsigned short x1, unsigned short * x2, unsigned short * x3)
{
  return flex_read_axis_limit_status_rtn(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_axis_limit_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned short * x2;
  unsigned short * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_axis_limit_status_rtn", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_axis_limit_status_rtn(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_axis_limit_status_rtn _cffi_d_flex_read_axis_limit_status_rtn
#endif

static long _cffi_d_flex_read_axis_status(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_axis_status(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_axis_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_axis_status", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_axis_status(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_axis_status _cffi_d_flex_read_axis_status
#endif

static long _cffi_d_flex_read_axis_status_rtn(unsigned char x0, unsigned char x1, unsigned short * x2)
{
  return flex_read_axis_status_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_axis_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_axis_status_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_axis_status_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_axis_status_rtn _cffi_d_flex_read_axis_status_rtn
#endif

static long _cffi_d_flex_read_blend_status(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_blend_status(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_blend_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_blend_status", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_blend_status(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_blend_status _cffi_d_flex_read_blend_status
#endif

static long _cffi_d_flex_read_blend_status_rtn(unsigned char x0, unsigned char x1, unsigned short * x2)
{
  return flex_read_blend_status_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_blend_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_blend_status_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_blend_status_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_blend_status_rtn _cffi_d_flex_read_blend_status_rtn
#endif

static long _cffi_d_flex_read_board_temperature(unsigned char x0, double * x1)
{
  return flex_read_board_temperature(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_board_temperature(PyObject *self, PyObject *args)
{
  unsigned char x0;
  double * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_board_temperature", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(61), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_board_temperature(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_board_temperature _cffi_d_flex_read_board_temperature
#endif

static long _cffi_d_flex_read_breakpoint_status(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_read_breakpoint_status(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_breakpoint_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_breakpoint_status", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_breakpoint_status(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_breakpoint_status _cffi_d_flex_read_breakpoint_status
#endif

static long _cffi_d_flex_read_breakpoint_status_rtn(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short * x3)
{
  return flex_read_breakpoint_status_rtn(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_breakpoint_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_breakpoint_status_rtn", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_breakpoint_status_rtn(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_breakpoint_status_rtn _cffi_d_flex_read_breakpoint_status_rtn
#endif

static long _cffi_d_flex_read_buffer(unsigned char x0, unsigned char x1, unsigned long x2, unsigned char x3)
{
  return flex_read_buffer(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_buffer(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_buffer", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_buffer(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_buffer _cffi_d_flex_read_buffer
#endif

static long _cffi_d_flex_read_buffer_rtn(unsigned char x0, unsigned char x1, unsigned long x2, long * x3)
{
  return flex_read_buffer_rtn(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_buffer_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  long * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_buffer_rtn", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_buffer_rtn(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_buffer_rtn _cffi_d_flex_read_buffer_rtn
#endif

static long _cffi_d_flex_read_cap_pos(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_cap_pos(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_cap_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_cap_pos", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_cap_pos(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_cap_pos _cffi_d_flex_read_cap_pos
#endif

static long _cffi_d_flex_read_cap_pos_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_cap_pos_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_cap_pos_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_cap_pos_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_cap_pos_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_cap_pos_rtn _cffi_d_flex_read_cap_pos_rtn
#endif

static long _cffi_d_flex_read_csr_rtn(unsigned char x0, unsigned short * x1)
{
  return flex_read_csr_rtn(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_csr_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_csr_rtn", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_csr_rtn(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_csr_rtn _cffi_d_flex_read_csr_rtn
#endif

static long _cffi_d_flex_read_dac(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_dac(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_dac(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_dac", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_dac(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_dac _cffi_d_flex_read_dac
#endif

static long _cffi_d_flex_read_dac_output_limit_status(unsigned char x0, unsigned char x1)
{
  return flex_read_dac_output_limit_status(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_dac_output_limit_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_dac_output_limit_status", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_dac_output_limit_status(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_dac_output_limit_status _cffi_d_flex_read_dac_output_limit_status
#endif

static long _cffi_d_flex_read_dac_output_limit_status_rtn(unsigned char x0, unsigned short * x1, unsigned short * x2)
{
  return flex_read_dac_output_limit_status_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_dac_output_limit_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  unsigned short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_dac_output_limit_status_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_dac_output_limit_status_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_dac_output_limit_status_rtn _cffi_d_flex_read_dac_output_limit_status_rtn
#endif

static long _cffi_d_flex_read_dac_rtn(unsigned char x0, unsigned char x1, short * x2)
{
  return flex_read_dac_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_dac_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_dac_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(151), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(151), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_dac_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_dac_rtn _cffi_d_flex_read_dac_rtn
#endif

static long _cffi_d_flex_read_description_rtn(unsigned char x0, unsigned char x1, char * x2)
{
  return flex_read_description_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_description_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  char * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_description_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(52), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(52), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_description_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_description_rtn _cffi_d_flex_read_description_rtn
#endif

static long _cffi_d_flex_read_drive_signal_status(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_drive_signal_status(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_drive_signal_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_drive_signal_status", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_drive_signal_status(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_drive_signal_status _cffi_d_flex_read_drive_signal_status
#endif

static long _cffi_d_flex_read_drive_signal_status_rtn(unsigned char x0, unsigned char x1, unsigned short * x2)
{
  return flex_read_drive_signal_status_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_drive_signal_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_drive_signal_status_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_drive_signal_status_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_drive_signal_status_rtn _cffi_d_flex_read_drive_signal_status_rtn
#endif

static long _cffi_d_flex_read_encoder(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_encoder(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_encoder(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_encoder", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_encoder(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_encoder _cffi_d_flex_read_encoder
#endif

static long _cffi_d_flex_read_encoder_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_encoder_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_encoder_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_encoder_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_encoder_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_encoder_rtn _cffi_d_flex_read_encoder_rtn
#endif

static long _cffi_d_flex_read_error_msg_detail_rtn(unsigned char x0, unsigned short * x1, unsigned short * x2, long * x3, unsigned short * x4, unsigned short * x5)
{
  return flex_read_error_msg_detail_rtn(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_error_msg_detail_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  unsigned short * x2;
  long * x3;
  unsigned short * x4;
  unsigned short * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_read_error_msg_detail_rtn", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_error_msg_detail_rtn(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_error_msg_detail_rtn _cffi_d_flex_read_error_msg_detail_rtn
#endif

static long _cffi_d_flex_read_error_msg_rtn(unsigned char x0, unsigned short * x1, unsigned short * x2, long * x3)
{
  return flex_read_error_msg_rtn(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_error_msg_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  unsigned short * x2;
  long * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_error_msg_rtn", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_error_msg_rtn(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_error_msg_rtn _cffi_d_flex_read_error_msg_rtn
#endif

static long _cffi_d_flex_read_follow_err(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_follow_err(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_follow_err(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_follow_err", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_follow_err(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_follow_err _cffi_d_flex_read_follow_err
#endif

static long _cffi_d_flex_read_follow_err_rtn(unsigned char x0, unsigned char x1, short * x2)
{
  return flex_read_follow_err_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_follow_err_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_follow_err_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(151), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(151), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_follow_err_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_follow_err_rtn _cffi_d_flex_read_follow_err_rtn
#endif

static long _cffi_d_flex_read_home_input_status(unsigned char x0, unsigned char x1)
{
  return flex_read_home_input_status(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_home_input_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_home_input_status", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_home_input_status(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_home_input_status _cffi_d_flex_read_home_input_status
#endif

static long _cffi_d_flex_read_home_input_status_rtn(unsigned char x0, unsigned short * x1)
{
  return flex_read_home_input_status_rtn(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_home_input_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_home_input_status_rtn", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_home_input_status_rtn(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_home_input_status_rtn _cffi_d_flex_read_home_input_status_rtn
#endif

static long _cffi_d_flex_read_hs_cap_status(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_hs_cap_status(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_hs_cap_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_hs_cap_status", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_hs_cap_status(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_hs_cap_status _cffi_d_flex_read_hs_cap_status
#endif

static long _cffi_d_flex_read_hs_cap_status_rtn(unsigned char x0, unsigned char x1, unsigned short * x2)
{
  return flex_read_hs_cap_status_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_hs_cap_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_hs_cap_status_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_hs_cap_status_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_hs_cap_status_rtn _cffi_d_flex_read_hs_cap_status_rtn
#endif

static long _cffi_d_flex_read_mcs_rtn(unsigned char x0, unsigned short * x1)
{
  return flex_read_mcs_rtn(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_mcs_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_mcs_rtn", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_mcs_rtn(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_mcs_rtn _cffi_d_flex_read_mcs_rtn
#endif

static long _cffi_d_flex_read_motion_io_execution_data(long x0, long x1, TnimcMotionIOExecution x2, NIMC_DATA * x3)
{
  return flex_read_motion_io_execution_data(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_motion_io_execution_data(PyObject *self, PyObject *args)
{
  long x0;
  long x1;
  TnimcMotionIOExecution x2;
  NIMC_DATA * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_motion_io_execution_data", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, long);
  if (x0 == (long)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, long);
  if (x1 == (long)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(15), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (NIMC_DATA *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_motion_io_execution_data(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_motion_io_execution_data _cffi_d_flex_read_motion_io_execution_data
#endif

static long _cffi_d_flex_read_port(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_port(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_port(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_port", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_port(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_port _cffi_d_flex_read_port
#endif

static long _cffi_d_flex_read_port_rtn(unsigned char x0, unsigned char x1, unsigned short * x2)
{
  return flex_read_port_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_port_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_port_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_port_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_port_rtn _cffi_d_flex_read_port_rtn
#endif

static long _cffi_d_flex_read_pos(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_pos(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_pos", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_pos(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_pos _cffi_d_flex_read_pos
#endif

static long _cffi_d_flex_read_pos_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_pos_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_pos_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_pos_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_pos_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_pos_rtn _cffi_d_flex_read_pos_rtn
#endif

static long _cffi_d_flex_read_program_status(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_program_status(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_program_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_program_status", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_program_status(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_program_status _cffi_d_flex_read_program_status
#endif

static long _cffi_d_flex_read_program_status_rtn(unsigned char x0, unsigned char x1, unsigned short * x2)
{
  return flex_read_program_status_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_program_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_program_status_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_program_status_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_program_status_rtn _cffi_d_flex_read_program_status_rtn
#endif

static long _cffi_d_flex_read_rdb(unsigned char x0, unsigned short * x1, unsigned short * x2, unsigned char * x3, unsigned short * x4, unsigned short * x5)
{
  return flex_read_rdb(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_rdb(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short * x1;
  unsigned short * x2;
  unsigned char * x3;
  unsigned short * x4;
  unsigned short * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_read_rdb", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(184), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(184), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_rdb(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_rdb _cffi_d_flex_read_rdb
#endif

static long _cffi_d_flex_read_reference_status(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned char x4)
{
  return flex_read_reference_status(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_reference_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_read_reference_status", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_reference_status(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_reference_status _cffi_d_flex_read_reference_status
#endif

static long _cffi_d_flex_read_reference_status_rtn(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned short * x4)
{
  return flex_read_reference_status_rtn(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_reference_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned short * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_read_reference_status_rtn", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_reference_status_rtn(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_reference_status_rtn _cffi_d_flex_read_reference_status_rtn
#endif

static long _cffi_d_flex_read_registry_rtn(unsigned char x0, unsigned char x1, REGSTRY * x2)
{
  return flex_read_registry_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_registry_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  REGSTRY * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_registry_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(85), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (REGSTRY *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(85), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_registry_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_registry_rtn _cffi_d_flex_read_registry_rtn
#endif

static long _cffi_d_flex_read_rpm(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_rpm(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_rpm(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_rpm", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_rpm(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_rpm _cffi_d_flex_read_rpm
#endif

static long _cffi_d_flex_read_rpm_rtn(unsigned char x0, unsigned char x1, double * x2)
{
  return flex_read_rpm_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_rpm_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  double * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_rpm_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(61), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_rpm_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_rpm_rtn _cffi_d_flex_read_rpm_rtn
#endif

static long _cffi_d_flex_read_steps_gen(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_steps_gen(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_steps_gen(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_steps_gen", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_steps_gen(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_steps_gen _cffi_d_flex_read_steps_gen
#endif

static long _cffi_d_flex_read_steps_gen_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_steps_gen_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_steps_gen_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_steps_gen_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_steps_gen_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_steps_gen_rtn _cffi_d_flex_read_steps_gen_rtn
#endif

static long _cffi_d_flex_read_target_pos(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_target_pos(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_target_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_target_pos", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_target_pos(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_target_pos _cffi_d_flex_read_target_pos
#endif

static long _cffi_d_flex_read_target_pos_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_target_pos_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_target_pos_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_target_pos_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_target_pos_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_target_pos_rtn _cffi_d_flex_read_target_pos_rtn
#endif

static long _cffi_d_flex_read_trajectory_data(unsigned char x0, unsigned char x1)
{
  return flex_read_trajectory_data(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_trajectory_data(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_trajectory_data", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_trajectory_data(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_trajectory_data _cffi_d_flex_read_trajectory_data
#endif

static long _cffi_d_flex_read_trajectory_data_rtn(unsigned char x0, long * x1)
{
  return flex_read_trajectory_data_rtn(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_trajectory_data_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  long * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_read_trajectory_data_rtn", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_trajectory_data_rtn(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_trajectory_data_rtn _cffi_d_flex_read_trajectory_data_rtn
#endif

static long _cffi_d_flex_read_trajectory_status(unsigned char x0, unsigned char x1, unsigned short x2, unsigned char x3)
{
  return flex_read_trajectory_status(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_trajectory_status(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_trajectory_status", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_trajectory_status(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_trajectory_status _cffi_d_flex_read_trajectory_status
#endif

static long _cffi_d_flex_read_trajectory_status_rtn(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short * x3)
{
  return flex_read_trajectory_status_rtn(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_trajectory_status_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_read_trajectory_status_rtn", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_trajectory_status_rtn(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_trajectory_status_rtn _cffi_d_flex_read_trajectory_status_rtn
#endif

static long _cffi_d_flex_read_var(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_var(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_var(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_var", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_var(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_var _cffi_d_flex_read_var
#endif

static long _cffi_d_flex_read_var_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_var_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_var_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_var_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_var_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_var_rtn _cffi_d_flex_read_var_rtn
#endif

static long _cffi_d_flex_read_velocity(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_velocity(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_velocity(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_velocity", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_velocity(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_velocity _cffi_d_flex_read_velocity
#endif

static long _cffi_d_flex_read_velocity_rtn(unsigned char x0, unsigned char x1, long * x2)
{
  return flex_read_velocity_rtn(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_velocity_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_velocity_rtn", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_velocity_rtn(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_velocity_rtn _cffi_d_flex_read_velocity_rtn
#endif

static long _cffi_d_flex_read_vs_pos(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_read_vs_pos(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_vs_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_read_vs_pos", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_vs_pos(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_vs_pos _cffi_d_flex_read_vs_pos
#endif

static long _cffi_d_flex_read_vs_pos_rtn(unsigned char x0, unsigned char x1, long * x2, long * x3, long * x4)
{
  return flex_read_vs_pos_rtn(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_read_vs_pos_rtn(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long * x2;
  long * x3;
  long * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_read_vs_pos_rtn", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_read_vs_pos_rtn(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_read_vs_pos_rtn _cffi_d_flex_read_vs_pos_rtn
#endif

static long _cffi_d_flex_reset_defaults(unsigned char x0)
{
  return flex_reset_defaults(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_reset_defaults(PyObject *self, PyObject *arg0)
{
  unsigned char x0;
  long result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_reset_defaults(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_reset_defaults _cffi_d_flex_reset_defaults
#endif

static long _cffi_d_flex_reset_encoder(unsigned char x0, unsigned char x1, long x2, unsigned char x3)
{
  return flex_reset_encoder(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_reset_encoder(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_reset_encoder", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_reset_encoder(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_reset_encoder _cffi_d_flex_reset_encoder
#endif

static long _cffi_d_flex_reset_pos(unsigned char x0, unsigned char x1, long x2, long x3, unsigned char x4)
{
  return flex_reset_pos(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_reset_pos(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long x2;
  long x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_reset_pos", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, long);
  if (x2 == (long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, long);
  if (x3 == (long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_reset_pos(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_reset_pos _cffi_d_flex_reset_pos
#endif

static long _cffi_d_flex_run_prog(unsigned char x0, unsigned char x1)
{
  return flex_run_prog(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_run_prog(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_run_prog", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_run_prog(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_run_prog _cffi_d_flex_run_prog
#endif

static long _cffi_d_flex_save_defaults(unsigned char x0)
{
  return flex_save_defaults(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_save_defaults(PyObject *self, PyObject *arg0)
{
  unsigned char x0;
  long result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_save_defaults(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_save_defaults _cffi_d_flex_save_defaults
#endif

static long _cffi_d_flex_select_signal(unsigned char x0, unsigned short x1, unsigned short x2)
{
  return flex_select_signal(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_select_signal(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_select_signal", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_select_signal(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_select_signal _cffi_d_flex_select_signal
#endif

static long _cffi_d_flex_set_adc_range(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_set_adc_range(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_adc_range(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_adc_range", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_adc_range(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_adc_range _cffi_d_flex_set_adc_range
#endif

static long _cffi_d_flex_set_breakpoint_output_momo(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned char x4)
{
  return flex_set_breakpoint_output_momo(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_breakpoint_output_momo(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_set_breakpoint_output_momo", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_breakpoint_output_momo(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_breakpoint_output_momo _cffi_d_flex_set_breakpoint_output_momo
#endif

static long _cffi_d_flex_set_home_polarity(unsigned char x0, unsigned short x1)
{
  return flex_set_home_polarity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_home_polarity(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_set_home_polarity", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_home_polarity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_home_polarity _cffi_d_flex_set_home_polarity
#endif

static long _cffi_d_flex_set_inhibit_output_momo(unsigned char x0, unsigned short x1, unsigned short x2)
{
  return flex_set_inhibit_output_momo(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_inhibit_output_momo(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_inhibit_output_momo", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_inhibit_output_momo(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_inhibit_output_momo _cffi_d_flex_set_inhibit_output_momo
#endif

static long _cffi_d_flex_set_irq_mask(unsigned char x0, unsigned short x1)
{
  return flex_set_irq_mask(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_irq_mask(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_set_irq_mask", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_irq_mask(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_irq_mask _cffi_d_flex_set_irq_mask
#endif

static long _cffi_d_flex_set_limit_input_polarity(unsigned char x0, unsigned short x1, unsigned short x2)
{
  return flex_set_limit_input_polarity(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_limit_input_polarity(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned short x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_limit_input_polarity", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_limit_input_polarity(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_limit_input_polarity _cffi_d_flex_set_limit_input_polarity
#endif

static long _cffi_d_flex_set_op_mode(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_set_op_mode(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_op_mode(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_op_mode", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_op_mode(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_op_mode _cffi_d_flex_set_op_mode
#endif

static long _cffi_d_flex_set_port(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3, unsigned char x4)
{
  return flex_set_port(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_port(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  unsigned char x4;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "flex_set_port", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned char);
  if (x4 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_port(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_port _cffi_d_flex_set_port
#endif

static long _cffi_d_flex_set_port_direction(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_set_port_direction(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_port_direction(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_port_direction", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_port_direction(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_port_direction _cffi_d_flex_set_port_direction
#endif

static long _cffi_d_flex_set_port_pol(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_set_port_pol(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_port_pol(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_port_pol", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_port_pol(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_port_pol _cffi_d_flex_set_port_pol
#endif

static long _cffi_d_flex_set_status_momo(unsigned char x0, unsigned char x1, unsigned char x2)
{
  return flex_set_status_momo(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_status_momo(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_status_momo", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_status_momo(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_status_momo _cffi_d_flex_set_status_momo
#endif

static long _cffi_d_flex_set_stepper_loop_mode(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_set_stepper_loop_mode(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_set_stepper_loop_mode(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_set_stepper_loop_mode", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_set_stepper_loop_mode(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_set_stepper_loop_mode _cffi_d_flex_set_stepper_loop_mode
#endif

static long _cffi_d_flex_setf64(unsigned char x0, unsigned char x1, unsigned short x2, double x3)
{
  return flex_setf64(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_setf64(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  double x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_setf64", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = (double)_cffi_to_c_double(arg3);
  if (x3 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_setf64(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_setf64 _cffi_d_flex_setf64
#endif

static long _cffi_d_flex_setu32(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long x3)
{
  return flex_setu32(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_setu32(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_setu32", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned long);
  if (x3 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_setu32(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_setu32 _cffi_d_flex_setu32
#endif

static long _cffi_d_flex_start(unsigned char x0, unsigned char x1, unsigned short x2)
{
  return flex_start(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_start(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "flex_start", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_start(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_start _cffi_d_flex_start
#endif

static long _cffi_d_flex_stop_motion(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3)
{
  return flex_stop_motion(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_stop_motion(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_stop_motion", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_stop_motion(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_stop_motion _cffi_d_flex_stop_motion
#endif

static long _cffi_d_flex_stop_prog(unsigned char x0, unsigned char x1)
{
  return flex_stop_prog(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_stop_prog(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "flex_stop_prog", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_stop_prog(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_stop_prog _cffi_d_flex_stop_prog
#endif

static long _cffi_d_flex_sub_vars(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3)
{
  return flex_sub_vars(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_sub_vars(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_sub_vars", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_sub_vars(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_sub_vars _cffi_d_flex_sub_vars
#endif

static long _cffi_d_flex_wait_for_blend_complete(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long x3, long x4, unsigned short * x5)
{
  return flex_wait_for_blend_complete(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_wait_for_blend_complete(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long x3;
  long x4;
  unsigned short * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_wait_for_blend_complete", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned long);
  if (x3 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, long);
  if (x4 == (long)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_wait_for_blend_complete(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_wait_for_blend_complete _cffi_d_flex_wait_for_blend_complete
#endif

static long _cffi_d_flex_wait_for_move_complete(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long x3, long x4, unsigned short * x5)
{
  return flex_wait_for_move_complete(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_wait_for_move_complete(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long x3;
  long x4;
  unsigned short * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_wait_for_move_complete", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned long);
  if (x3 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, long);
  if (x4 == (long)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_wait_for_move_complete(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_wait_for_move_complete _cffi_d_flex_wait_for_move_complete
#endif

static long _cffi_d_flex_wait_on_event(unsigned char x0, unsigned char x1, unsigned short x2, unsigned short x3, unsigned short x4, unsigned short x5, unsigned short x6, unsigned short x7, unsigned char x8)
{
  return flex_wait_on_event(x0, x1, x2, x3, x4, x5, x6, x7, x8);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_wait_on_event(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned short x3;
  unsigned short x4;
  unsigned short x5;
  unsigned short x6;
  unsigned short x7;
  unsigned char x8;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject *arg6;
  PyObject *arg7;
  PyObject *arg8;

  if (!PyArg_UnpackTuple(args, "flex_wait_on_event", 9, 9, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &arg7, &arg8))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned short);
  if (x4 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, unsigned short);
  if (x5 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x6 = _cffi_to_c_int(arg6, unsigned short);
  if (x6 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x7 = _cffi_to_c_int(arg7, unsigned short);
  if (x7 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x8 = _cffi_to_c_int(arg8, unsigned char);
  if (x8 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_wait_on_event(x0, x1, x2, x3, x4, x5, x6, x7, x8); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_wait_on_event _cffi_d_flex_wait_on_event
#endif

static long _cffi_d_flex_wait_reference(unsigned char x0, unsigned char x1, unsigned short x2, unsigned long x3, unsigned long x4, unsigned short * x5)
{
  return flex_wait_reference(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_wait_reference(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned short x2;
  unsigned long x3;
  unsigned long x4;
  unsigned short * x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_wait_reference", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned short);
  if (x2 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned long);
  if (x3 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x4 = _cffi_to_c_int(arg4, unsigned long);
  if (x4 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg5, (char **)&x5);
  if (datasize != 0) {
    x5 = ((size_t)datasize) <= 640 ? (unsigned short *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg5, (char **)&x5,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_wait_reference(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_wait_reference _cffi_d_flex_wait_reference
#endif

static long _cffi_d_flex_write_buffer(unsigned char x0, unsigned char x1, unsigned long x2, unsigned short x3, long * x4, unsigned char x5)
{
  return flex_write_buffer(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_write_buffer(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned long x2;
  unsigned short x3;
  long * x4;
  unsigned char x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "flex_write_buffer", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned long);
  if (x2 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned short);
  if (x3 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(65), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(65), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = _cffi_to_c_int(arg5, unsigned char);
  if (x5 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_write_buffer(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_flex_write_buffer _cffi_d_flex_write_buffer
#endif

static long _cffi_d_flex_xor_vars(unsigned char x0, unsigned char x1, unsigned char x2, unsigned char x3)
{
  return flex_xor_vars(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_flex_xor_vars(PyObject *self, PyObject *args)
{
  unsigned char x0;
  unsigned char x1;
  unsigned char x2;
  unsigned char x3;
  long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "flex_xor_vars", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned char);
  if (x0 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned char);
  if (x1 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = flex_xor_vars(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, long);
  return pyresult;
}
#else
#  define _cffi_f_flex_xor_vars _cffi_d_flex_xor_vars
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "TnimcAxisConfigurationParameterEnable", (void *)_cffi_const_TnimcAxisConfigurationParameterEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcCammingParameterMasterCycle", (void *)_cffi_const_TnimcCammingParameterMasterCycle, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcCammingParameterMasterOffset", (void *)_cffi_const_TnimcCammingParameterMasterOffset, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcCammingParameterSlaveOffset", (void *)_cffi_const_TnimcCammingParameterSlaveOffset, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOExecutionForwardLimitStatus", (void *)_cffi_const_TnimcMotionIOExecutionForwardLimitStatus, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOExecutionForwardSoftwareLimitStatus", (void *)_cffi_const_TnimcMotionIOExecutionForwardSoftwareLimitStatus, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOExecutionHomeInputStatus", (void *)_cffi_const_TnimcMotionIOExecutionHomeInputStatus, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOExecutionInPositionStatus", (void *)_cffi_const_TnimcMotionIOExecutionInPositionStatus, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOExecutionInhibitInStatus", (void *)_cffi_const_TnimcMotionIOExecutionInhibitInStatus, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOExecutionReverseLimitStatus", (void *)_cffi_const_TnimcMotionIOExecutionReverseLimitStatus, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOExecutionReverseSoftwareLimitStatus", (void *)_cffi_const_TnimcMotionIOExecutionReverseSoftwareLimitStatus, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterForwardLimitEnable", (void *)_cffi_const_TnimcMotionIOParameterForwardLimitEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterForwardLimitPolarity", (void *)_cffi_const_TnimcMotionIOParameterForwardLimitPolarity, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterForwardSoftwareLimitEnable", (void *)_cffi_const_TnimcMotionIOParameterForwardSoftwareLimitEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterForwardSoftwareLimitPosition", (void *)_cffi_const_TnimcMotionIOParameterForwardSoftwareLimitPosition, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterHomeInputEnable", (void *)_cffi_const_TnimcMotionIOParameterHomeInputEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterHomeInputPolarity", (void *)_cffi_const_TnimcMotionIOParameterHomeInputPolarity, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterInPositionEnable", (void *)_cffi_const_TnimcMotionIOParameterInPositionEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterInPositionPolarity", (void *)_cffi_const_TnimcMotionIOParameterInPositionPolarity, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterInhibitInEnable", (void *)_cffi_const_TnimcMotionIOParameterInhibitInEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterInhibitInPolarity", (void *)_cffi_const_TnimcMotionIOParameterInhibitInPolarity, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterReverseLimitEnable", (void *)_cffi_const_TnimcMotionIOParameterReverseLimitEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterReverseLimitPolarity", (void *)_cffi_const_TnimcMotionIOParameterReverseLimitPolarity, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterReverseSoftwareLimitEnable", (void *)_cffi_const_TnimcMotionIOParameterReverseSoftwareLimitEnable, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMotionIOParameterReverseSoftwareLimitPosition", (void *)_cffi_const_TnimcMotionIOParameterReverseSoftwareLimitPosition, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMoveConstraintAcceleration", (void *)_cffi_const_TnimcMoveConstraintAcceleration, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMoveConstraintAccelerationJerk", (void *)_cffi_const_TnimcMoveConstraintAccelerationJerk, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMoveConstraintDeceleration", (void *)_cffi_const_TnimcMoveConstraintDeceleration, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMoveConstraintDecelerationJerk", (void *)_cffi_const_TnimcMoveConstraintDecelerationJerk, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "TnimcMoveConstraintVelocity", (void *)_cffi_const_TnimcMoveConstraintVelocity, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "flex_acquire_trajectory_data", (void *)_cffi_f_flex_acquire_trajectory_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 521), (void *)_cffi_d_flex_acquire_trajectory_data },
  { "flex_add_vars", (void *)_cffi_f_flex_add_vars, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_flex_add_vars },
  { "flex_and_vars", (void *)_cffi_f_flex_and_vars, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_flex_and_vars },
  { "flex_begin_store", (void *)_cffi_f_flex_begin_store, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_begin_store },
  { "flex_blend", (void *)_cffi_f_flex_blend, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_blend },
  { "flex_check_blend_complete_status", (void *)_cffi_f_flex_check_blend_complete_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 379), (void *)_cffi_d_flex_check_blend_complete_status },
  { "flex_check_buffer", (void *)_cffi_f_flex_check_buffer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_check_buffer },
  { "flex_check_buffer_rtn", (void *)_cffi_f_flex_check_buffer_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 241), (void *)_cffi_d_flex_check_buffer_rtn },
  { "flex_check_move_complete_status", (void *)_cffi_f_flex_check_move_complete_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 379), (void *)_cffi_d_flex_check_move_complete_status },
  { "flex_check_reference", (void *)_cffi_f_flex_check_reference, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 385), (void *)_cffi_d_flex_check_reference },
  { "flex_clear_buffer", (void *)_cffi_f_flex_clear_buffer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_clear_buffer },
  { "flex_clear_pu_status", (void *)_cffi_f_flex_clear_pu_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_flex_clear_pu_status },
  { "flex_communicate", (void *)_cffi_f_flex_communicate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 180), (void *)_cffi_d_flex_communicate },
  { "flex_config_axis", (void *)_cffi_f_flex_config_axis, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 202), (void *)_cffi_d_flex_config_axis },
  { "flex_config_gear_master", (void *)_cffi_f_flex_config_gear_master, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_config_gear_master },
  { "flex_config_inhibit_output", (void *)_cffi_f_flex_config_inhibit_output, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 420), (void *)_cffi_d_flex_config_inhibit_output },
  { "flex_config_mc_criteria", (void *)_cffi_f_flex_config_mc_criteria, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 405), (void *)_cffi_d_flex_config_mc_criteria },
  { "flex_config_vect_spc", (void *)_cffi_f_flex_config_vect_spc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 195), (void *)_cffi_d_flex_config_vect_spc },
  { "flex_configure_breakpoint", (void *)_cffi_f_flex_configure_breakpoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 420), (void *)_cffi_d_flex_configure_breakpoint },
  { "flex_configure_breakpoint_output", (void *)_cffi_f_flex_configure_breakpoint_output, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 392), (void *)_cffi_d_flex_configure_breakpoint_output },
  { "flex_configure_buffer", (void *)_cffi_f_flex_configure_buffer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 230), (void *)_cffi_d_flex_configure_buffer },
  { "flex_configure_camming_master", (void *)_cffi_f_flex_configure_camming_master, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 30), (void *)_cffi_d_flex_configure_camming_master },
  { "flex_configure_drive_signal", (void *)_cffi_f_flex_configure_drive_signal, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 427), (void *)_cffi_d_flex_configure_drive_signal },
  { "flex_configure_encoder_filter", (void *)_cffi_f_flex_configure_encoder_filter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_configure_encoder_filter },
  { "flex_configure_encoder_polarity", (void *)_cffi_f_flex_configure_encoder_polarity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 521), (void *)_cffi_d_flex_configure_encoder_polarity },
  { "flex_configure_hs_capture", (void *)_cffi_f_flex_configure_hs_capture, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 392), (void *)_cffi_d_flex_configure_hs_capture },
  { "flex_configure_pwm_output", (void *)_cffi_f_flex_configure_pwm_output, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 392), (void *)_cffi_d_flex_configure_pwm_output },
  { "flex_configure_stepper_output", (void *)_cffi_f_flex_configure_stepper_output, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 420), (void *)_cffi_d_flex_configure_stepper_output },
  { "flex_div_vars", (void *)_cffi_f_flex_div_vars, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_flex_div_vars },
  { "flex_enable_1394_watchdog", (void *)_cffi_f_flex_enable_1394_watchdog, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_flex_enable_1394_watchdog },
  { "flex_enable_adcs", (void *)_cffi_f_flex_enable_adcs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_enable_adcs },
  { "flex_enable_auto_start", (void *)_cffi_f_flex_enable_auto_start, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_enable_auto_start },
  { "flex_enable_axis", (void *)_cffi_f_flex_enable_axis, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 210), (void *)_cffi_d_flex_enable_axis },
  { "flex_enable_axis_limit", (void *)_cffi_f_flex_enable_axis_limit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 521), (void *)_cffi_d_flex_enable_axis_limit },
  { "flex_enable_breakpoint", (void *)_cffi_f_flex_enable_breakpoint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_enable_breakpoint },
  { "flex_enable_camming", (void *)_cffi_f_flex_enable_camming, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 42), (void *)_cffi_d_flex_enable_camming },
  { "flex_enable_camming_single_axis", (void *)_cffi_f_flex_enable_camming_single_axis, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 36), (void *)_cffi_d_flex_enable_camming_single_axis },
  { "flex_enable_encoders", (void *)_cffi_f_flex_enable_encoders, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_flex_enable_encoders },
  { "flex_enable_gearing", (void *)_cffi_f_flex_enable_gearing, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_flex_enable_gearing },
  { "flex_enable_gearing_single_axis", (void *)_cffi_f_flex_enable_gearing_single_axis, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_enable_gearing_single_axis },
  { "flex_enable_home_inputs", (void *)_cffi_f_flex_enable_home_inputs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_flex_enable_home_inputs },
  { "flex_enable_hs_capture", (void *)_cffi_f_flex_enable_hs_capture, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_enable_hs_capture },
  { "flex_enable_shutdown", (void *)_cffi_f_flex_enable_shutdown, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_flex_enable_shutdown },
  { "flex_end_store", (void *)_cffi_f_flex_end_store, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_end_store },
  { "flex_find_home", (void *)_cffi_f_flex_find_home, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_find_home },
  { "flex_find_index", (void *)_cffi_f_flex_find_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 324), (void *)_cffi_d_flex_find_index },
  { "flex_find_reference", (void *)_cffi_f_flex_find_reference, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_find_reference },
  { "flex_flush_rdb", (void *)_cffi_f_flex_flush_rdb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_flex_flush_rdb },
  { "flex_get_error_description", (void *)_cffi_f_flex_get_error_description, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 527), (void *)_cffi_d_flex_get_error_description },
  { "flex_get_last_error", (void *)_cffi_f_flex_get_last_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 479), (void *)_cffi_d_flex_get_last_error },
  { "flex_get_motion_board_info", (void *)_cffi_f_flex_get_motion_board_info, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 465), (void *)_cffi_d_flex_get_motion_board_info },
  { "flex_get_motion_board_info_string", (void *)_cffi_f_flex_get_motion_board_info_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 459), (void *)_cffi_d_flex_get_motion_board_info_string },
  { "flex_get_motion_board_name", (void *)_cffi_f_flex_get_motion_board_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 54), (void *)_cffi_d_flex_get_motion_board_name },
  { "flex_get_reference_parameter", (void *)_cffi_f_flex_get_reference_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 216), (void *)_cffi_d_flex_get_reference_parameter },
  { "flex_getf64", (void *)_cffi_f_flex_getf64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 305), (void *)_cffi_d_flex_getf64 },
  { "flex_getu32", (void *)_cffi_f_flex_getu32, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 344), (void *)_cffi_d_flex_getu32 },
  { "flex_initialize_controller", (void *)_cffi_f_flex_initialize_controller, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 50), (void *)_cffi_d_flex_initialize_controller },
  { "flex_insert_program_label", (void *)_cffi_f_flex_insert_program_label, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_flex_insert_program_label },
  { "flex_jump_on_event", (void *)_cffi_f_flex_jump_on_event, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 435), (void *)_cffi_d_flex_jump_on_event },
  { "flex_load_acceleration", (void *)_cffi_f_flex_load_acceleration, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 364), (void *)_cffi_d_flex_load_acceleration },
  { "flex_load_advanced_control_parameter", (void *)_cffi_f_flex_load_advanced_control_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 364), (void *)_cffi_d_flex_load_advanced_control_parameter },
  { "flex_load_axis_configuration_parameter", (void *)_cffi_f_flex_load_axis_configuration_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_flex_load_axis_configuration_parameter },
  { "flex_load_base_vel", (void *)_cffi_f_flex_load_base_vel, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_load_base_vel },
  { "flex_load_blend_fact", (void *)_cffi_f_flex_load_blend_fact, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 169), (void *)_cffi_d_flex_load_blend_fact },
  { "flex_load_bp_modulus", (void *)_cffi_f_flex_load_bp_modulus, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 281), (void *)_cffi_d_flex_load_bp_modulus },
  { "flex_load_camming_parameter", (void *)_cffi_f_flex_load_camming_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 6), (void *)_cffi_d_flex_load_camming_parameter },
  { "flex_load_circular_arc", (void *)_cffi_f_flex_load_circular_arc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 267), (void *)_cffi_d_flex_load_circular_arc },
  { "flex_load_commutation_parameter", (void *)_cffi_f_flex_load_commutation_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 311), (void *)_cffi_d_flex_load_commutation_parameter },
  { "flex_load_counts_steps_rev", (void *)_cffi_f_flex_load_counts_steps_rev, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 350), (void *)_cffi_d_flex_load_counts_steps_rev },
  { "flex_load_dac", (void *)_cffi_f_flex_load_dac, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 169), (void *)_cffi_d_flex_load_dac },
  { "flex_load_delay", (void *)_cffi_f_flex_load_delay, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 455), (void *)_cffi_d_flex_load_delay },
  { "flex_load_description", (void *)_cffi_f_flex_load_description, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 87), (void *)_cffi_d_flex_load_description },
  { "flex_load_follow_err", (void *)_cffi_f_flex_load_follow_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_load_follow_err },
  { "flex_load_gear_ratio", (void *)_cffi_f_flex_load_gear_ratio, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 330), (void *)_cffi_d_flex_load_gear_ratio },
  { "flex_load_helical_arc", (void *)_cffi_f_flex_load_helical_arc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 258), (void *)_cffi_d_flex_load_helical_arc },
  { "flex_load_motion_io_parameter", (void *)_cffi_f_flex_load_motion_io_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 18), (void *)_cffi_d_flex_load_motion_io_parameter },
  { "flex_load_move_constraint", (void *)_cffi_f_flex_load_move_constraint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 24), (void *)_cffi_d_flex_load_move_constraint },
  { "flex_load_pid_parameters", (void *)_cffi_f_flex_load_pid_parameters, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 76), (void *)_cffi_d_flex_load_pid_parameters },
  { "flex_load_pos_bp", (void *)_cffi_f_flex_load_pos_bp, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 142), (void *)_cffi_d_flex_load_pos_bp },
  { "flex_load_pos_modulus", (void *)_cffi_f_flex_load_pos_modulus, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 281), (void *)_cffi_d_flex_load_pos_modulus },
  { "flex_load_program_time_slice", (void *)_cffi_f_flex_load_program_time_slice, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_load_program_time_slice },
  { "flex_load_pwm_duty", (void *)_cffi_f_flex_load_pwm_duty, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_load_pwm_duty },
  { "flex_load_reference_parameter", (void *)_cffi_f_flex_load_reference_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 223), (void *)_cffi_d_flex_load_reference_parameter },
  { "flex_load_rpm", (void *)_cffi_f_flex_load_rpm, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 103), (void *)_cffi_d_flex_load_rpm },
  { "flex_load_rpm_thresh", (void *)_cffi_f_flex_load_rpm_thresh, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 103), (void *)_cffi_d_flex_load_rpm_thresh },
  { "flex_load_rpsps", (void *)_cffi_f_flex_load_rpsps, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 317), (void *)_cffi_d_flex_load_rpsps },
  { "flex_load_run_stop_threshold", (void *)_cffi_f_flex_load_run_stop_threshold, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_load_run_stop_threshold },
  { "flex_load_scurve_time", (void *)_cffi_f_flex_load_scurve_time, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_load_scurve_time },
  { "flex_load_single_pid_parameter", (void *)_cffi_f_flex_load_single_pid_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 398), (void *)_cffi_d_flex_load_single_pid_parameter },
  { "flex_load_spherical_arc", (void *)_cffi_f_flex_load_spherical_arc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 248), (void *)_cffi_d_flex_load_spherical_arc },
  { "flex_load_sw_lim_pos", (void *)_cffi_f_flex_load_sw_lim_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 135), (void *)_cffi_d_flex_load_sw_lim_pos },
  { "flex_load_target_pos", (void *)_cffi_f_flex_load_target_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 142), (void *)_cffi_d_flex_load_target_pos },
  { "flex_load_torque_lim", (void *)_cffi_f_flex_load_torque_lim, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 153), (void *)_cffi_d_flex_load_torque_lim },
  { "flex_load_torque_offset", (void *)_cffi_f_flex_load_torque_offset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 162), (void *)_cffi_d_flex_load_torque_offset },
  { "flex_load_var", (void *)_cffi_f_flex_load_var, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 67), (void *)_cffi_d_flex_load_var },
  { "flex_load_velocity", (void *)_cffi_f_flex_load_velocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 142), (void *)_cffi_d_flex_load_velocity },
  { "flex_load_velocity_filter_parameter", (void *)_cffi_f_flex_load_velocity_filter_parameter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 398), (void *)_cffi_d_flex_load_velocity_filter_parameter },
  { "flex_load_velocity_override", (void *)_cffi_f_flex_load_velocity_override, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 109), (void *)_cffi_d_flex_load_velocity_override },
  { "flex_load_velocity_threshold", (void *)_cffi_f_flex_load_velocity_threshold, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 281), (void *)_cffi_d_flex_load_velocity_threshold },
  { "flex_load_vs_pos", (void *)_cffi_f_flex_load_vs_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 127), (void *)_cffi_d_flex_load_vs_pos },
  { "flex_lshift_var", (void *)_cffi_f_flex_lshift_var, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 92), (void *)_cffi_d_flex_lshift_var },
  { "flex_mult_vars", (void *)_cffi_f_flex_mult_vars, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_flex_mult_vars },
  { "flex_not_var", (void *)_cffi_f_flex_not_var, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_not_var },
  { "flex_object_mem_manage", (void *)_cffi_f_flex_object_mem_manage, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_object_mem_manage },
  { "flex_or_vars", (void *)_cffi_f_flex_or_vars, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_flex_or_vars },
  { "flex_pause_prog", (void *)_cffi_f_flex_pause_prog, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_pause_prog },
  { "flex_read_adc16", (void *)_cffi_f_flex_read_adc16, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_adc16 },
  { "flex_read_adc16_rtn", (void *)_cffi_f_flex_read_adc16_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_adc16_rtn },
  { "flex_read_axis_limit_status", (void *)_cffi_f_flex_read_axis_limit_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 505), (void *)_cffi_d_flex_read_axis_limit_status },
  { "flex_read_axis_limit_status_rtn", (void *)_cffi_f_flex_read_axis_limit_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 510), (void *)_cffi_d_flex_read_axis_limit_status_rtn },
  { "flex_read_axis_status", (void *)_cffi_f_flex_read_axis_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_axis_status },
  { "flex_read_axis_status_rtn", (void *)_cffi_f_flex_read_axis_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 295), (void *)_cffi_d_flex_read_axis_status_rtn },
  { "flex_read_blend_status", (void *)_cffi_f_flex_read_blend_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_blend_status },
  { "flex_read_blend_status_rtn", (void *)_cffi_f_flex_read_blend_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 295), (void *)_cffi_d_flex_read_blend_status_rtn },
  { "flex_read_board_temperature", (void *)_cffi_f_flex_read_board_temperature, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 59), (void *)_cffi_d_flex_read_board_temperature },
  { "flex_read_breakpoint_status", (void *)_cffi_f_flex_read_breakpoint_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_read_breakpoint_status },
  { "flex_read_breakpoint_status_rtn", (void *)_cffi_f_flex_read_breakpoint_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 379), (void *)_cffi_d_flex_read_breakpoint_status_rtn },
  { "flex_read_buffer", (void *)_cffi_f_flex_read_buffer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 281), (void *)_cffi_d_flex_read_buffer },
  { "flex_read_buffer_rtn", (void *)_cffi_f_flex_read_buffer_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 275), (void *)_cffi_d_flex_read_buffer_rtn },
  { "flex_read_cap_pos", (void *)_cffi_f_flex_read_cap_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_cap_pos },
  { "flex_read_cap_pos_rtn", (void *)_cffi_f_flex_read_cap_pos_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_cap_pos_rtn },
  { "flex_read_csr_rtn", (void *)_cffi_f_flex_read_csr_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 470), (void *)_cffi_d_flex_read_csr_rtn },
  { "flex_read_dac", (void *)_cffi_f_flex_read_dac, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_dac },
  { "flex_read_dac_output_limit_status", (void *)_cffi_f_flex_read_dac_output_limit_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_read_dac_output_limit_status },
  { "flex_read_dac_output_limit_status_rtn", (void *)_cffi_f_flex_read_dac_output_limit_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 474), (void *)_cffi_d_flex_read_dac_output_limit_status_rtn },
  { "flex_read_dac_rtn", (void *)_cffi_f_flex_read_dac_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 148), (void *)_cffi_d_flex_read_dac_rtn },
  { "flex_read_description_rtn", (void *)_cffi_f_flex_read_description_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 87), (void *)_cffi_d_flex_read_description_rtn },
  { "flex_read_drive_signal_status", (void *)_cffi_f_flex_read_drive_signal_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_drive_signal_status },
  { "flex_read_drive_signal_status_rtn", (void *)_cffi_f_flex_read_drive_signal_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 295), (void *)_cffi_d_flex_read_drive_signal_status_rtn },
  { "flex_read_encoder", (void *)_cffi_f_flex_read_encoder, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_encoder },
  { "flex_read_encoder_rtn", (void *)_cffi_f_flex_read_encoder_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_encoder_rtn },
  { "flex_read_error_msg_detail_rtn", (void *)_cffi_f_flex_read_error_msg_detail_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 485), (void *)_cffi_d_flex_read_error_msg_detail_rtn },
  { "flex_read_error_msg_rtn", (void *)_cffi_f_flex_read_error_msg_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 479), (void *)_cffi_d_flex_read_error_msg_rtn },
  { "flex_read_follow_err", (void *)_cffi_f_flex_read_follow_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_follow_err },
  { "flex_read_follow_err_rtn", (void *)_cffi_f_flex_read_follow_err_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 148), (void *)_cffi_d_flex_read_follow_err_rtn },
  { "flex_read_home_input_status", (void *)_cffi_f_flex_read_home_input_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_read_home_input_status },
  { "flex_read_home_input_status_rtn", (void *)_cffi_f_flex_read_home_input_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 470), (void *)_cffi_d_flex_read_home_input_status_rtn },
  { "flex_read_hs_cap_status", (void *)_cffi_f_flex_read_hs_cap_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_hs_cap_status },
  { "flex_read_hs_cap_status_rtn", (void *)_cffi_f_flex_read_hs_cap_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 295), (void *)_cffi_d_flex_read_hs_cap_status_rtn },
  { "flex_read_mcs_rtn", (void *)_cffi_f_flex_read_mcs_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 470), (void *)_cffi_d_flex_read_mcs_rtn },
  { "flex_read_motion_io_execution_data", (void *)_cffi_f_flex_read_motion_io_execution_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 12), (void *)_cffi_d_flex_read_motion_io_execution_data },
  { "flex_read_port", (void *)_cffi_f_flex_read_port, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_port },
  { "flex_read_port_rtn", (void *)_cffi_f_flex_read_port_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 295), (void *)_cffi_d_flex_read_port_rtn },
  { "flex_read_pos", (void *)_cffi_f_flex_read_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_pos },
  { "flex_read_pos_rtn", (void *)_cffi_f_flex_read_pos_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_pos_rtn },
  { "flex_read_program_status", (void *)_cffi_f_flex_read_program_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_program_status },
  { "flex_read_program_status_rtn", (void *)_cffi_f_flex_read_program_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 295), (void *)_cffi_d_flex_read_program_status_rtn },
  { "flex_read_rdb", (void *)_cffi_f_flex_read_rdb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 493), (void *)_cffi_d_flex_read_rdb },
  { "flex_read_reference_status", (void *)_cffi_f_flex_read_reference_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 398), (void *)_cffi_d_flex_read_reference_status },
  { "flex_read_reference_status_rtn", (void *)_cffi_f_flex_read_reference_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 413), (void *)_cffi_d_flex_read_reference_status_rtn },
  { "flex_read_registry_rtn", (void *)_cffi_f_flex_read_registry_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 82), (void *)_cffi_d_flex_read_registry_rtn },
  { "flex_read_rpm", (void *)_cffi_f_flex_read_rpm, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_rpm },
  { "flex_read_rpm_rtn", (void *)_cffi_f_flex_read_rpm_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 98), (void *)_cffi_d_flex_read_rpm_rtn },
  { "flex_read_steps_gen", (void *)_cffi_f_flex_read_steps_gen, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_steps_gen },
  { "flex_read_steps_gen_rtn", (void *)_cffi_f_flex_read_steps_gen_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_steps_gen_rtn },
  { "flex_read_target_pos", (void *)_cffi_f_flex_read_target_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_target_pos },
  { "flex_read_target_pos_rtn", (void *)_cffi_f_flex_read_target_pos_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_target_pos_rtn },
  { "flex_read_trajectory_data", (void *)_cffi_f_flex_read_trajectory_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_read_trajectory_data },
  { "flex_read_trajectory_data_rtn", (void *)_cffi_f_flex_read_trajectory_data_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 63), (void *)_cffi_d_flex_read_trajectory_data_rtn },
  { "flex_read_trajectory_status", (void *)_cffi_f_flex_read_trajectory_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 338), (void *)_cffi_d_flex_read_trajectory_status },
  { "flex_read_trajectory_status_rtn", (void *)_cffi_f_flex_read_trajectory_status_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 379), (void *)_cffi_d_flex_read_trajectory_status_rtn },
  { "flex_read_var", (void *)_cffi_f_flex_read_var, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_var },
  { "flex_read_var_rtn", (void *)_cffi_f_flex_read_var_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_var_rtn },
  { "flex_read_velocity", (void *)_cffi_f_flex_read_velocity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_velocity },
  { "flex_read_velocity_rtn", (void *)_cffi_f_flex_read_velocity_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_flex_read_velocity_rtn },
  { "flex_read_vs_pos", (void *)_cffi_f_flex_read_vs_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_read_vs_pos },
  { "flex_read_vs_pos_rtn", (void *)_cffi_f_flex_read_vs_pos_rtn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 120), (void *)_cffi_d_flex_read_vs_pos_rtn },
  { "flex_reset_defaults", (void *)_cffi_f_flex_reset_defaults, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_flex_reset_defaults },
  { "flex_reset_encoder", (void *)_cffi_f_flex_reset_encoder, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 142), (void *)_cffi_d_flex_reset_encoder },
  { "flex_reset_pos", (void *)_cffi_f_flex_reset_pos, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 135), (void *)_cffi_d_flex_reset_pos },
  { "flex_run_prog", (void *)_cffi_f_flex_run_prog, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_run_prog },
  { "flex_save_defaults", (void *)_cffi_f_flex_save_defaults, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_flex_save_defaults },
  { "flex_select_signal", (void *)_cffi_f_flex_select_signal, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 516), (void *)_cffi_d_flex_select_signal },
  { "flex_set_adc_range", (void *)_cffi_f_flex_set_adc_range, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_set_adc_range },
  { "flex_set_breakpoint_output_momo", (void *)_cffi_f_flex_set_breakpoint_output_momo, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 398), (void *)_cffi_d_flex_set_breakpoint_output_momo },
  { "flex_set_home_polarity", (void *)_cffi_f_flex_set_home_polarity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_flex_set_home_polarity },
  { "flex_set_inhibit_output_momo", (void *)_cffi_f_flex_set_inhibit_output_momo, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 516), (void *)_cffi_d_flex_set_inhibit_output_momo },
  { "flex_set_irq_mask", (void *)_cffi_f_flex_set_irq_mask, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 501), (void *)_cffi_d_flex_set_irq_mask },
  { "flex_set_limit_input_polarity", (void *)_cffi_f_flex_set_limit_input_polarity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 516), (void *)_cffi_d_flex_set_limit_input_polarity },
  { "flex_set_op_mode", (void *)_cffi_f_flex_set_op_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_set_op_mode },
  { "flex_set_port", (void *)_cffi_f_flex_set_port, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 195), (void *)_cffi_d_flex_set_port },
  { "flex_set_port_direction", (void *)_cffi_f_flex_set_port_direction, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_set_port_direction },
  { "flex_set_port_pol", (void *)_cffi_f_flex_set_port_pol, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_set_port_pol },
  { "flex_set_status_momo", (void *)_cffi_f_flex_set_status_momo, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_flex_set_status_momo },
  { "flex_set_stepper_loop_mode", (void *)_cffi_f_flex_set_stepper_loop_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_set_stepper_loop_mode },
  { "flex_setf64", (void *)_cffi_f_flex_setf64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 311), (void *)_cffi_d_flex_setf64 },
  { "flex_setu32", (void *)_cffi_f_flex_setu32, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 350), (void *)_cffi_d_flex_setu32 },
  { "flex_start", (void *)_cffi_f_flex_start, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_flex_start },
  { "flex_stop_motion", (void *)_cffi_f_flex_stop_motion, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 392), (void *)_cffi_d_flex_stop_motion },
  { "flex_stop_prog", (void *)_cffi_f_flex_stop_prog, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 72), (void *)_cffi_d_flex_stop_prog },
  { "flex_sub_vars", (void *)_cffi_f_flex_sub_vars, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_flex_sub_vars },
  { "flex_wait_for_blend_complete", (void *)_cffi_f_flex_wait_for_blend_complete, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 356), (void *)_cffi_d_flex_wait_for_blend_complete },
  { "flex_wait_for_move_complete", (void *)_cffi_f_flex_wait_for_move_complete, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 356), (void *)_cffi_d_flex_wait_for_move_complete },
  { "flex_wait_on_event", (void *)_cffi_f_flex_wait_on_event, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 444), (void *)_cffi_d_flex_wait_on_event },
  { "flex_wait_reference", (void *)_cffi_f_flex_wait_reference, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 371), (void *)_cffi_d_flex_wait_reference },
  { "flex_write_buffer", (void *)_cffi_f_flex_write_buffer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 287), (void *)_cffi_d_flex_write_buffer },
  { "flex_xor_vars", (void *)_cffi_f_flex_xor_vars, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_flex_xor_vars },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "axisIndex", offsetof(NIMC_CAMMING_ENABLE_DATA, axisIndex),
                 sizeof(((NIMC_CAMMING_ENABLE_DATA *)0)->axisIndex),
                 _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "enable", offsetof(NIMC_CAMMING_ENABLE_DATA, enable),
              sizeof(((NIMC_CAMMING_ENABLE_DATA *)0)->enable),
              _CFFI_OP(_CFFI_OP_NOOP, 48) },
  { "position", offsetof(NIMC_CAMMING_ENABLE_DATA, position),
                sizeof(((NIMC_CAMMING_ENABLE_DATA *)0)->position),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "longData", offsetof(NIMC_DATA, longData),
                sizeof(((NIMC_DATA *)0)->longData),
                _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "boolData", offsetof(NIMC_DATA, boolData),
                sizeof(((NIMC_DATA *)0)->boolData),
                _CFFI_OP(_CFFI_OP_NOOP, 48) },
  { "doubleData", offsetof(NIMC_DATA, doubleData),
                  sizeof(((NIMC_DATA *)0)->doubleData),
                  _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "kp", offsetof(PID, kp),
          sizeof(((PID *)0)->kp),
          _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "ki", offsetof(PID, ki),
          sizeof(((PID *)0)->ki),
          _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "ilim", offsetof(PID, ilim),
            sizeof(((PID *)0)->ilim),
            _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "kd", offsetof(PID, kd),
          sizeof(((PID *)0)->kd),
          _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "td", offsetof(PID, td),
          sizeof(((PID *)0)->td),
          _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "kv", offsetof(PID, kv),
          sizeof(((PID *)0)->kv),
          _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "aff", offsetof(PID, aff),
           sizeof(((PID *)0)->aff),
           _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "vff", offsetof(PID, vff),
           sizeof(((PID *)0)->vff),
           _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "device", offsetof(REGSTRY, device),
              sizeof(((REGSTRY *)0)->device),
              _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "type", offsetof(REGSTRY, type),
            sizeof(((REGSTRY *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 39) },
  { "pstart", offsetof(REGSTRY, pstart),
              sizeof(((REGSTRY *)0)->pstart),
              _CFFI_OP(_CFFI_OP_NOOP, 44) },
  { "size", offsetof(REGSTRY, size),
            sizeof(((REGSTRY *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 44) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$NIMC_CAMMING_ENABLE_DATA", 535, _CFFI_F_CHECK_FIELDS,
    sizeof(NIMC_CAMMING_ENABLE_DATA), offsetof(struct _cffi_align_typedef_NIMC_CAMMING_ENABLE_DATA, y), 0, 3 },
  { "$NIMC_DATA", 536, _CFFI_F_CHECK_FIELDS,
    sizeof(NIMC_DATA), offsetof(struct _cffi_align_typedef_NIMC_DATA, y), 3, 3 },
  { "$PID", 537, _CFFI_F_CHECK_FIELDS,
    sizeof(PID), offsetof(struct _cffi_align_typedef_PID, y), 6, 8 },
  { "$REGSTRY", 538, _CFFI_F_CHECK_FIELDS,
    sizeof(REGSTRY), offsetof(struct _cffi_align_typedef_REGSTRY, y), 14, 4 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$TnimcAxisConfigurationParameter", 3, _cffi_prim_int(sizeof(TnimcAxisConfigurationParameter), ((TnimcAxisConfigurationParameter)-1) <= 0),
    "TnimcAxisConfigurationParameterEnable" },
  { "$TnimcCammingParameter", 9, _cffi_prim_int(sizeof(TnimcCammingParameter), ((TnimcCammingParameter)-1) <= 0),
    "TnimcCammingParameterMasterCycle,TnimcCammingParameterMasterOffset,TnimcCammingParameterSlaveOffset" },
  { "$TnimcMotionIOExecution", 15, _cffi_prim_int(sizeof(TnimcMotionIOExecution), ((TnimcMotionIOExecution)-1) <= 0),
    "TnimcMotionIOExecutionForwardLimitStatus,TnimcMotionIOExecutionReverseLimitStatus,TnimcMotionIOExecutionForwardSoftwareLimitStatus,TnimcMotionIOExecutionReverseSoftwareLimitStatus,TnimcMotionIOExecutionHomeInputStatus,TnimcMotionIOExecutionInhibitInStatus,TnimcMotionIOExecutionInPositionStatus" },
  { "$TnimcMotionIOParameter", 21, _cffi_prim_int(sizeof(TnimcMotionIOParameter), ((TnimcMotionIOParameter)-1) <= 0),
    "TnimcMotionIOParameterForwardLimitEnable,TnimcMotionIOParameterReverseLimitEnable,TnimcMotionIOParameterForwardSoftwareLimitEnable,TnimcMotionIOParameterReverseSoftwareLimitEnable,TnimcMotionIOParameterHomeInputEnable,TnimcMotionIOParameterForwardLimitPolarity,TnimcMotionIOParameterReverseLimitPolarity,TnimcMotionIOParameterHomeInputPolarity,TnimcMotionIOParameterForwardSoftwareLimitPosition,TnimcMotionIOParameterReverseSoftwareLimitPosition,TnimcMotionIOParameterInhibitInEnable,TnimcMotionIOParameterInhibitInPolarity,TnimcMotionIOParameterInPositionEnable,TnimcMotionIOParameterInPositionPolarity" },
  { "$TnimcMoveConstraint", 27, _cffi_prim_int(sizeof(TnimcMoveConstraint), ((TnimcMoveConstraint)-1) <= 0),
    "TnimcMoveConstraintVelocity,TnimcMoveConstraintAcceleration,TnimcMoveConstraintDeceleration,TnimcMoveConstraintAccelerationJerk,TnimcMoveConstraintDecelerationJerk" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "NIMC_CAMMING_ENABLE_DATA", 535 },
  { "NIMC_DATA", 536 },
  { "PID", 537 },
  { "REGISTRY", 538 },
  { "REGSTRY", 538 },
  { "TnimcAxisConfigurationParameter", 3 },
  { "TnimcCammingParameter", 9 },
  { "TnimcMotionIOExecution", 15 },
  { "TnimcMotionIOParameter", 21 },
  { "TnimcMoveConstraint", 27 },
  { "f32", 112 },
  { "f64", 34 },
  { "i16", 156 },
  { "i32", 1 },
  { "i8", 95 },
  { "tBoolean", 44 },
  { "u16", 39 },
  { "u32", 44 },
  { "u8", 48 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  227,  /* num_globals */
  4,  /* num_struct_unions */
  5,  /* num_enums */
  19,  /* num_typenames */
  NULL,  /* no includes */
  539,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__flex_motion_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__flex_motion_cffi(void) { return NULL; }
#  else
     init_flex_motion_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__flex_motion_cffi(void)
{
  return _cffi_init("_flex_motion_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_flex_motion_cffi(void)
{
  _cffi_init("_flex_motion_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
